#!/bin/sh
#
# Script:   QB64PE_install.sh
# UpDate:   October 20, 2022
# Release:  r04
# Author:   Fifi
# e-mail:   pckb@wanadoo.fr
# Licence:  CC-By-Sa
#
# Goal of this script:
#
# This script is intended to be used with any version of ArchLinux, Bridge,
# CentOS, Chakra, Debian, elementary, Fedora, LinuxMint, LMDE, Manjaro, Neon,
# Raspbian, Ubuntu (including its spin off) and Zorin, all of those both for
# Desktop and Server flavors (if the servers use a GUI).
#
# This script:
#
# - downloads and installs QB64PE and its required dependencies and the excellent
#   InForm GDE tool from Fellippe Heitor,
# - allows QB64PE to be called from anywhere like any de facto standard compiler
#   when using the simple command: "qb64pe",
# - creates links for QB64PE and InForm on the desktop and in the apps. menu,
# - when the installation is done via this script, offers to nicely uninstall QB64PE
#   & InForm as well as the desktop and menu starters icons if you restart the script.
#
# Credits:
# --------
# Thanks for their times and tremandous advice helping me to make this script
# (as well as others related scripts) to:
#
# From the https://forum.ubuntu-fr.org community (by alphabetical order): Amiralgaby,
# Bousky, Clémentv, grim7reaper, epehj, hoper, Hizoka, MicP, nesthib, pingouinux,
# The Uploader, tiramiseb, Watael and many others.
#
# From the https://forums.fedora-fr.org community (by alphabetical order): fgland,
# madko, nouvo09, pingou, remi and many others.
#
# From the http://www.manjaro.fr community (by alphabetical order):
# lemust83, ewolnux, loubrix, papajoke, patri-arch, smurf, waitnsea and many
# others.
#
# From the https://www.centos.org community (by alphabetical order): bob,
# Emma, MartinR, stevemowbray, TrevorH and many others.
#
# From the https://ubuntuforums.org community (by alphabetical order): steeldriver,
# and many others.
#
# From the https://qb64phoenix.com/forum/index.php community: Special thanks to Fellippe Heitor,
# Flukiluke, Donald, doppler and many others.
#
# Note:
# -----
#
# This script isn't supported by Galleon (the QB64's dad) nor by the QB64PE forum
# members but by me in its G-WAN sub section. So, if you need explanations about
# it or if you need to report any problem or broken links please feel free to
# contact me directly by mail: pckb@wanadoo.fr
#
# This script downloads the last stable release of QB64PE located on the qb64pe.org
# web site.
#
# To cleanly uninstall the complete QB64PE & InForm package when using
# it to install these products, just restart the script and just type "N" or "n"
# for "no" when the script proposes to reinstall QB64PE (the default is Yes).
#
# History:
# --------
# r00 : Restart from my previous QB64_install.sh, rev 36
#       So, all the previous features are included.
# r01 : Now, install my own fork named QB64PE 0.8.1 and my adapted InForm-pe
# r02 : Add the backup of the /opt/qb64pe folder in /home/username/backup-qb64pe when you
#       uninstall or reinstall QB64PE with this script.
# r03 : Now, Install QB64PE v 3.2.0 and my adapted GDI InForm-pe v 1.3 for QB64PE.
#
# todo:
# -----
#       We need the community help to test this script with other distributions and to correct
#       the dialog messages and translate in many as possible other mother tongues such as
#       Deutch, Spanish, etc whatever you're confortable with.
# --------------------------------------------------------------------------------
#
# test if the gcc setting is --enable default-pie
#
check_gcc()
{
    if [ -n "`gcc -v -E 2>&1 | grep 'Configured with' | sed 's/--/\n--/g' | grep enable-default-pie`" ]
        then
            GCC_SETTING="1"
        else
            GCC_SETTING="0"
    fi
}
# --------------------------------------------------------------------------------
#
# test the compiled file type
#
check_type()
{
    FILE_TYPE=$(file -b --mime-type $FILETOTEST)
    if [ $(file -b --mime-type $FILETOTEST) = "application/x-executable" ]
        then
            FILE_MIME="1"
        else
            FILE_MIME="0"
    fi
}
# --------------------------------------------------------------------------------
#
# set the dialog messages in english
#
set_language_us()
{
    dlg000="${BACK}\n--------------------------------------------------------------------------------\n"
    dlg001="Please, hit the [Enter] key to continue..."
    dlg002="${BLUE}\nHello ${GREEN}$ME${BLUE},\n\nThis script installs (and uninstalls) ${RED}$QB64PEREV ${BLUE}and\nthe excellent${RED} InForm GDE $INFORMREV ${BLUE}from${RED} Fellippe Heitor.${BLUE}\n\nThis script ${RED}$SCRIPTREV${BLUE} will display messages using different colors.\n\n- in blue:   information of what's going to be done by the script\n\n${YELLOW}- in yellow: question you've to answer to continue the execution of the script\n\n${RED}- in red:    important info or problem with an answer to the previous question\n\n${GREEN}- in green:  response of your OS or action following your response\n\n${BACK}- in white:  important action done on your system.\n\n"
    dlg003="\n${GREEN}OK, the account user name${RED} $MYUSERNAME ${GREEN}is valid on this system."
    dlg004="\n${GREEN}Sorry, the account user name${RED} $MYUSERNAME ${GREEN}isn't allowed on this system.\n\n${BLUE}Please retry."
    dlg005="Please enter your account user name to continue: ? "
    dlg006="\n${GREEN}Your account user name is empty.\n"
    dlg007="Do you want to enter your user name to continue: Y/n (empty return = Yes)? "
    dlg008="\n${RED}Sorry, this script can't continue without knowing your user name.${BLUE}\n\nGoodbye.\n${BACK}$dlg000"
    dlg009="${BLUE}Hello ${GREEN}$ME,"
    dlg010="\n${RED}WARNING\n-------\n"
    dlg011="${RED}This script can't be used without the root privileges (i.e.${BACK} [sudo]${RED} or ${BACK}[su]${RED} or ${BACK}[su -]${RED}).\n\n${GREEN}Please restart the script with the command: ${BACK}[sudo ./QB64PE_install.sh]${GREEN} or start\na ${RED}root session${GREEN} \nusing ${BACK}[su]${GREEN} or ${BACK}[su -]${GREEN}, then start ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg012="${RED}This script can't be used without the root privileges (${BACK}[su -]${RED}).\n\n${GREEN}Please start a ${RED}root session${GREEN} using ${BACK}[su]${GREEN} or ${RED}([su -])${GREEN} then goto\nthe folder where you've installed this script and start ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg013="\n${RED}WARNING\n-------\n\n${GREEN}You're using the ${RED}root${GREEN} account priviledges.\n\nSo, I can't guess ${RED}your real account user name${GREEN} and this script needs this\ninformation to continue.\n"
    dlg014="${BACK}Deleting the previous QB64PE folder.${BACK}"
    dlg015="${BACK}\nDeleting the previous temporary install folder.${BACK}"
    dlg016="${BACK}\nDeleting the QB64PE IDE icon starter desktop.${BACK}"
    dlg016b="${BACK}\nDeleting the InForm GDE icon starter desktop.${BACK}"
    dlg016d="${BACK}\nDeleting the QB64PE link desktop.${BACK}"
    dlg017="${BACK}\nDeleting the QB64PE path and the bash starting file.${BACK}"
    dlg018="${BACK}\nDeleting the QB64PE IDE menu entry.${BACK}"
    dlg018b="${BACK}\nDeleting the InForm GDE menu entry.${BACK}"
    dlg019="\n${GREEN}QB64PE and InForm were cleanly removed from your computer.\n\n${BLUE}Now, we're ready to start a new install process."
    dlg019b="Do you want to reinstall QB64PE and InForm Y/n (empty return = Yes)? : "
    dlg019c="\n${GREEN}You didn't reinstall QB64PE and InForm.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
    dlg020="Are you ready to uninstall QB64PE Y/n (empty return = Yes)? : "
    dlg021="\n${GREEN}Ok, we're going to cleanly uninstall QB64PE.\n"
    dlg022="\n${GREEN}Ok, QB64PE is going to be cleanly removed from your computer then reinstalled.\n\n${BLUE}However before to process, you may need to backup your sources (.bas) files.\n\nIf this is the case, please hold this script and do your backup, then continue."
    dlg022b="\n${GREEN}Ok, QB64PE is going to be cleanly removed from your computer then reinstalled."
    dlg023="\n${BLUE}Hey ${GREEN}$MYUSERNAME${BLUE} using the${RED} root priviledges${BLUE},"
    dlg024="\n${BLUE}Sorry, but as already said:"
    dlg025="\n${GREEN}QB64PE was already installed on your computer with the QB64PE_install.sh script\nand was not cleanly uninstalled from your computer leaving unwanted files.\n"
    dlg026="${RED}So, it's not possible to reinstall it right away."
    dlg027="Do you want to cleanly uninstall prior reinstalling Y/n (empty return = Yes)? "
    dlg028="${GREEN}\nPlease uninstall QB64PE before to install it again.\n\n${BLUE}Goodbye.${BACK}$dlg000\n"
    dlg029="\n${GREEN}You didn't install QB64PE.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
    dlg030="\n${GREEN}The QB64PE installation starts. Please be patient...\n"
    dlg031="${BLUE}\nYou're all set."
    dlg032="Are you ready to install QB64PE & InForm: Y/n (empty return = Yes) ? "
    dlg033="${GREEN}OK, there will be only an entry in the application menu.${BACK}\n"
    dlg034="${GREEN}Well, you'll have icon starters on your desktop and entries in the menu.${BACK}\n"
    dlg035="Do you want to put icon starters on your desktop: Y/n (empty return = Yes)? "
    dlg036="${GREEN}Well, the $TEMPFOLDER folder will be deleted.${BACK}"
    dlg037="${GREEN}OK, the $TEMPFOLDER folder will not be deleted.${BACK}"
    dlg038="${YELLOW}At the end of the script, do you want to keep the $TEMPFOLDER folder to"
    dlg039="check what was done during the installation: y/N (empty return = No)? "
    dlg040="${GREEN}\nBuilding library LibQB...\n${BACK}"
    dlg041="${GREEN}Building library FreeType...\n${BACK}"
    dlg042="${GREEN}Building User Additions...\n${BACK}"
    dlg043="${GREEN}Building library Core:FreeGLUT...\n${BACK}"
    dlg044="${GREEN}Building QB64PE...\n${BACK}"
    dlg045="${GREEN}\nCompiling QB64PE...\n${BACK}"
    dlg045b="${RED}\nQB64PE was created.\n${BACK}"
    dlg045c="${GREEN}Now compiling InForm with the new QB64PE compiler...\n${BACK}"
    dlg045d="\n${RED}\nInForm was created.\n${BACK}"
    dlg046="${GREEN}Installing QB64PE and InForm...\n${BACK}"
    dlg047="${GREEN}\nThe installation is complete.\n\n${GREEN}Now, you can finally run QB64PE from any terminal session ${RED}without being into the\nQB64PE's directory${GREEN} (as you would with GCC) just by typing ${RED}'qb64pe' ${GREEN}or running\nthe compile command line: ${RED}'qb64pe -x source_file.bas -o executable_file'\n${GREEN}and even adding the source and destination directories:\n${RED}'qb64pe -x /source_dir/source_file.bas -o /destination_dir/executable_file'\n"
    dlg048="${GREEN}Removing $TEMPFOLDER.\n${BACK}"
    dlg048b="${RED}You still have the $TEMPFOLDER folder to check what the script did.\n${BACK}"
    dlg049="${RED}\nUnfortunately, it appears that the qb64pe executable file was not created.\n\n${GREEN}This is usually an indication of a compile failure and you probably saw\nlots of error messages pop up on the screen.\n\nUsually these are due to missing packages needed for compilation.\n\nIf you need help, please feel free to post on the QB64PE forum\nor e-mail me at: admin@as2.com\n\nPlease detail what happened and the distribution you're using the\ncommands of the next line:\n\n${BACK}lsb_release -sd && lsb_release -sc && lsb_release -sr\n && uname -r"
    dlg050="${BLUE}Sorry for the inconvenience.\n\nGoodbye.\n${BACK}$dlg000\n"
    dlg051="${BLUE}\n\nThank you for using the QB64PE_install.sh script.\n\n${RED}To safely uninstall QB64PE & InForm-pe, just restart the script.\n\n${BLUE}All the best.\n${BACK}$dlg000\n"
    dlg052="${GREEN}\nCheck and if not present install the dependencies needed to compile QB64PE...\n${BACK}"
    dlg053="${GREEN}\nDownloading QB64PE and InForm...${BACK}\n"
    dlg054="${GREEN}Unpacking QB64PE and InForm...${BACK}"
    dlg055="${BLUE}Now, just two last questions:"
    dlg056="${BLUE}\n\nThe next step is to download and install QB64PE as well as all the relevent\ndependencies needed to compile QB64PE on $VENDOR $RELEASE.\n\nMeanwhile, be aware that this install can last up to 15 minutes due to the\ntime to download, compile and install QB64PE.\n\nSo, the speed of this installation depends both of the power of your machine\nand of your intrenet bandwith.\n"
    dlg057="${GREEN}You ended the script and nothing was done on your computer.\n\n${BLUE}Please restart this script when you need it.\n\nGoodbye.${BACK}$dlg000"
    dlg058="${GREEN}\nOK. Continuing the installation...${BACK}"
    dlg059="${BLUE}\nHello ${GREEN}$MYUSERNAME${BLUE} using the${RED} root priviledges${BLUE},\n\nNow, this script installs ${GREEN}$QB64PEREV${BLUE} as well as\nall the necessary dependencies accordingly to your distribution specifications.\n\nYour OS is: ${RED}$SYSTEM $VENDOR $RELEASE${BLUE} with the following characteristics:\n\n Name:   ${RED}$DISTRONAME\n ${BLUE}Flavor: ${RED}$FLAVOR bits\n ${BLUE}Kernel: ${RED}$KERNEL\n\n${BLUE}By default:\n\n The QB64PE install folder is: ${RED}$QB64PEFOLDER\n${BLUE} The TEMP install folder is: ${RED}$TEMPFOLDER\n\n"
    dlg060="${RED}Sorry but after ${BACK}9${RED} tries, I can't download $FILE2"
    dlg061="Do you wish to retry right now: y/N (empty return = No) ? : "
    dlg062="${GREEN}Retrying to download $SOURCE$FILE"
    dlg063="${RED}This script can't continue without $FILE2\n\n${GREEN}Please verify your internet connection and restart the script.\n\nIf the problem persists, please report it to admin@as2.com\n\n${BLUE}Goodbye.${BACK}$dlg000"
    dlg064="${RED}\nSorry but after ${BACK}5 ${RED}tries, I can't install $FILE"
    dlg065="Do you wish to retry right now: y/N (empty return = No)? : "
    dlg066="${GREEN}Retrying to install $FILE"
    dlg067="${RED}Sorry but this script can't continue without $FILE\n\n${GREEN}Please verify your internet connection and restart the script.\n${BLUE}Goodbye${BACK}$dlg000"
    dlg068="\n${BLUE}Hello $ME,${RED}\n\nYou must install lsb_release to use this script."
    dlg069="Do you want to install lsb_release now: Y/n (empty return = Yes) ? "
    dlg070="\n${RED}This script can't continue without lsb_release.\n\n${GREEN}Please install lsb_release and restart the script.\n\n${BLUE}Goodbye.${BACK}$dlg000"
    dlg071="${RED}Please, you must install wget to use this script."
    dlg072="Do you want to install wget now: Y/n (empty return = Yes) ? "
    dlg073="${GREEN}This script can't continue without wget.\nPlease install wget and restart the script.\n\n${BLUE}Goodbye.${BACK}$dlg000"
    dlg074="\n${BLUE}Hello $ME,\n\n${RED}You must use the root priviledges to use this script.\n\n${GREEN}Please restart this script using${BACK} [sudo] ${GREEN}or ${BACK}[su] ${GREEN}or ${BACK}[su -]${GREEN} accordingly with the\nsecurity policy of your OS.\n\n${BLUE}Goodbye.${BACK}\n\n--------------------------------------------------------------------------------\n"
    dlg075="${BLUE}\nThe script can backup your $QB64PEFOLDER into your /home/$MYUSERNAME/backup-qb64pe.${YELLOW}\n"
    dlg076="Do you want to backup your $QB64PEFOLDER Y/n (empty return = Yes )? "
    dlg077="${RED}\nOK, your $QB64PEFOLDER is not saved into /home/$MYUSERNAME/backup-qb64pe.${GREEN}\n\nPlease check what to do with your $QB64PEFOLDER folder (move or rename or delete\it) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg078="${GREEN}\nOK, the script is saving your $QB64PEFOLDER into /home/$MYUSERNAME/backup-qb64pe"
    dlg079="${RED}\nWARNING! the directory /home/$MYUSERNAME/backup-qb64pe already exists!\n"
    dlg080="So, your current /opt/qb64pe foldder wasn't saved, yet.\n\n${BLUE}Please check what to do with your previous /home/$MYUSERNAME/backup-qb64pe folder\n(move or rename or delete\nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg081="\n${GREEN}Now, QB64PE was saved into /home/$MYUSERNAME/backup-qb64pe\n"
    dlg082="Are you ready to remove the previous $QB64PEFOLDER now: Y/n (empty return = Yes) ? "
    dlg083="\n${GREEN}You didn't reinstall QB64PE and InForm.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
    dlg099="${RED}Thanks for their times and tremandous advice helping me to make this script to:\n\nFrom the https://forum.ubuntu-fr.org community (by alphabetical order):\nAmiralgaby, Bousky, Clémentv, grim7reaper, epehj, hoper, Hizoka, MicP, nesthib,\npingouinux, The Uploader, tiramiseb, Watael and many others.\n\nFrom the https://forums.fedora-fr.org community (by alphabetical order): fgland,\nmadko, nouvo09, pingou, remi and many others.\n\nFrom the http://www.manjaro.fr community (by alphabetical order): ewolnux,\nlemust83, loubrix, papajoke, patri-arch, smurf, waitnsea and many others.\n\nFrom the https://www.centos.org community (by alphabetical order): bob, Emma,\nMartinR, stevemowbray, TrevorH and many others.\n\nFrom the https://ubuntuforums.org community (by alphabetical order): steeldriver\nand many others.\n\nFrom the https://qb64phoenix.com/forum/index.php community: Donald, doppler,\nFlukiluke and many others.\n\nSpecial thanks to Fellippe Heitor for his open source project InForm."
}
# --------------------------------------------------------------------------------
#
# set the dialog messages in Italian
#
set_language_it()
{
    dlg000="${BACK}\n--------------------------------------------------------------------------------\n"
    dlg001="Per favore, premi il tasto [Invio] per continuare..."
    dlg002="${BLUE}\nCiao ${GREEN}$ME${BLUE},\n\nQuesto script viene installato (e disinstallato) ${RED}$QB64PEREV ${BLUE}and\ne l'eccellente ${RED} InForm $INFORMREV ${BLUE} ${BLUE}di${RED} Fellippe Heitor.${BLUE}\n\nQuesto script mostrerà i messaggi usando colori diversi.\n\n- in blu:    informazioni su ciò che verrà fatto dalla sceneggiatura\n\n${YELLOW}- in giallo: domanda a cui devi rispondere per continuare l'esecuzione della\n  sceneggiatura\n\n${RED}- in rosso:  informazioni importanti o problemi con una risposta alla domanda\n  precedente\n\n${GREEN}- in verde:  risposta del tuo sistema operativo o azione in seguito alla tua\n  risposta\n\n${BACK}- in bianco: importante azione fatta sul tuo sistema.\n\n"
    dlg003="\n${GREEN}OK, il nome utente dell'account${RED} $MYUSERNAME ${GREEN}è valido su questo sistema."
    dlg004="\n${GREEN}Siamo spiacenti, il nome utente dell'account${RED} $MYUSERNAME ${GREEN}non è consentito su questo sistema.\n\n${BLUE}Per favore riprova."
    dlg005="Inserisci il nome utente del tuo account per continuare: ? "
    dlg006="\n${GREEN}Il nome utente del tuo account è vuoto.\n"
    dlg007="Vuoi inserire il tuo nome utente per continuare: S/n (ritorno vuoto = Sì)? "
    dlg008="\n${RED}Spiacenti, questo script non può continuare senza conoscere il tuo nome utente.${BLUE}\n\nAddio.\n${BACK}$dlg000"
    dlg009="${BLUE}Ciao ${GREEN}$ME,"
    dlg010="\n${RED}AVVERTIMENTO\n------------\n"
    dlg011="${RED}Questo script non può essere utilizzato senza i privilegi di root (${BACK} [sudo]${RED} o ${BACK}[su]${RED} o ${BACK}[su -]${RED}).\n\n${GREEN}Si prega di riavviare lo script con il comando: ${BACK}[sudo ./QB64PE_install.sh]${GREEN} o avviare\nuna ${RED}sessione root${GREEN} \nutilizzando ${BACK}[su]${GREEN} o ${BACK}[su -]${GREEN}, quindi iniziare ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Addio.\n${BACK}$dlg000\n"
    dlg012="${RED}Questo script non può essere utilizzato senza i privilegi di root (${BACK}[su -]${RED}).\n\n${GREEN}Iniziare una  ${RED}sessione root${GREEN} usando ${BACK}[su]${GREEN} o ${RED}([su -])${GREEN} quindi vai\nalla cartella in cui hai installato questo script e avvia ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Addio.\n${BACK}$dlg000\n"
    dlg013="\n${RED}AVVERTIMENTO\n------------\n\n${GREEN}Stai utilizzando i privilegi dell'account ${RED}root${GREEN}.\n\nQuindi, non riesco a indovinare ${RED} il nome utente del tuo account reale${GREEN} e questo\nscript ha bisogno di questo information per continuare.\n"
    dlg014="${BACK}Eliminazione della precedente cartella QB64PE.${BACK}"
    dlg015="${BACK}\nEliminazione della precedente cartella di installazione temporanea.${BACK}"
    dlg016="${BACK}\nEliminazione del desktop di avvio di icone IDE QB64PE.${BACK}"
    dlg016b="${BACK}\nEliminazione del desktop di avvio di icone InForm GDE.${BACK}"
    dlg016d="${BACK}\nEliminazione del desktop di collegamento QB64PE.${BACK}"
    dlg017="${BACK}\nEliminazione del percorso QB64PE e del file di avvio di bash.${BACK}"
    dlg018="${BACK}\nEliminazione dela voce del menu IDE QB64PE.${BACK}"
    dlg018b="${BACK}\nEliminazione della voce di menu InForm GDE.${BACK}"
    dlg019="\n${GREEN}QB64PE e InForm sono stati rimossi dal tuo computer.\n\n${BLUE}Ora siamo pronti per iniziare una nuova procedura di installazione."
    dlg019b="Vuoi reinstallare QB64PE e InForm S/n (ritorno vuoto = Sì)? : "
    dlg019c="\n${GREEN}Non hai reinstallato QB64PE e InForm.\n${BLUE}\nPer favore, riprova quando sarai pronto.\n\nAddio.\n${BACK}$dlg000\n"
    dlg020="Sei pronto per disinstallare QB64PE S/n (ritorno vuoto = Sì)? : "
    dlg021="\n${GREEN}Ok, disinstalleremo in modo pulito QB64PE.\n"
    dlg022="\n${GREEN}Ok, QB64PE verrà rimosso dal computer e reinstallato.\n\n${BLUE}Tuttavia, prima di procedere, potrebbe essere necessario eseguire il backup dei file di origine (.bas).\n\nIn questo caso, tieni questo script e fai il tuo backup, quindi continua."
    dlg022b="\n${GREEN}Ok, QB64PE verrà rimosso dal computer e reinstallato."
    dlg023="\n${BLUE}Hey ${GREEN}$MYUSERNAME${BLUE} usando i privilegi root${RED} privilegi root${BLUE},"
    dlg024="\n${BLUE}Ci dispiace, ma come già detto:"
    dlg025="\n${GREEN}QB64PE era già installato sul tuo computer con lo script QB64PE_install.sh non è\ndisinstallato correttamente dal tuo computer lasciando file indesiderati.\n"
    dlg026="${RED}Quindi, non è possibile reinstallarlo subito."
    dlg027="Vuoi disinstallare in modo pulito la precedente reinstallazione di S/n (ritorno vuoto = Sì)? "
    dlg028="${GREEN}\nSi prega di disinstallare QB64PE prima di installarlo di nuovo.\n\n${BLUE}Addio.${BACK}$dlg000\n"
    dlg029="\n${GREEN}Non hai installato QB64PE.\n${BLUE}\nPer favore, riprova quando sarai pronto.\n\nAddio.\n${BACK}$dlg000\n"
    dlg030="\n${GREEN}L'installazione di QB64PE inizia. Per favore sii paziente...\n"
    dlg031="${BLUE}\nSei tutto pronto."
    dlg032="Sei pronto per installare QB64PE & InForm: S/n (ritorno vuoto = Sì) ? "
    dlg033="${GREEN}OK, ci sarà solo una voce nel menu dell'applicazione.${BACK}\n"
    dlg034="${GREEN}Bene, avrai gli antipasti delle icone sul desktop e le voci nel menu.${BACK}\n"
    dlg035="Vuoi mettere gli starter di icone sul desktop: S/n (ritorno vuoto = Sì)? "
    dlg036="${GREEN}Bene, la cartella $TEMPFOLDER sarà cancellata.${BACK}"
    dlg037="${GREEN}OK, la cartella $TEMPFOLDER non verrà cancellata.${BACK}"
    dlg038="${YELLOW}Alla fine dello script, si desidera mantenere la cartella $TEMPFOLDER per"
    dlg039="verificare cosa è stato fatto durante l'installazione: s/N (ritorno vuoto=No)? "
    dlg040="${GREEN}\nCostruire libreria LibQB...\n${BACK}"
    dlg041="${GREEN}Costruire libreria FreeType...\n${BACK}"
    dlg042="${GREEN}Creazione di aggiunte utente...\n${BACK}"
    dlg043="${GREEN}Costruire la libreria Core: FreeGLUT...\n${BACK}"
    dlg044="${GREEN}Costruire QB64PE...\n${BACK}"
    dlg045="${GREEN}\nCompilare QB64PE...\n${BACK}"
    dlg045b="${RED}QB64PE è stato creato.\n${BACK}"
    dlg045c="${GREEN}Ora compilare InForm con il nuovo compilatore QB64PE...\n${BACK}"
    dlg045d="${RED}\nInForm è stato creato.\n${BACK}"
    dlg046="${GREEN}Installazione di QB64PE e InForm...\n${BACK}"
    dlg047="${GREEN}\nL'installazione è completa.\n\n${RED}Ora puoi finalmente eseguire QB64PE da qualsiasi sessione del terminale\nsenza essere nella directory di QB64PE come faresti con GCC \nsemplicemente digitando 'qb64pe' o eseguendo la riga di comando di compilazione \n'qb64pe -x file_sorgente.bas -o file_eseguibile' ed eventualmente aggiungendo \nl'origine e la destinazione directory.\nqb64pe -x /source_directory/source_file.bas -o /destination_directory/executable_file\n"
    dlg048="${GREEN}Rimozione $TEMPFOLDER.\n${BACK}"
    dlg048b="${RED}Hai ancora la cartella $TEMPFOLDER per verificare cosa ha fatto lo script.\n${BACK}"
    dlg049="${RED}\nSfortunatamente, sembra che il file eseguibile qb64pe non sia stato creato.\n\n${GREEN}TQuesto di solito è un'indicazione di un errore di compilazione e probabilmente hai visto molti messaggi di errore apparire sullo schermo.\n\n Di solito sono dovuti alla mancanza dei pacchetti necessari per la compilazione.\n\n Se hai bisogno di aiuto, per favore sentitevi liberi di postare sul forum QB64PE\n o mandatemi un'e-mail a: admin@as2.com\n\n Per favore, descrivete cosa è successo e la distribuzione in cui state usando i\n comandi della riga successiva:\n\n${BACK}lsb_release -sd && lsb_release -sc && lsb_release -sr\n && uname -r"
    dlg050="${BLUE}Ci dispiace per l'inconvenienza.\n\nAddio.\n${BACK}$dlg000\n"
    dlg051="${BLUE}Grazie per aver utilizzato lo script QB64PE_install.sh.\n\n$${RED}To safely uninstall QB64PE & InForm-pe, just restart the script.\n\n{BLUE}Addio.\n${BACK}$dlg000\n"
    dlg052="${GREEN}\nControllare e se non presente installare le dipendenze necessarie per compilare QB64PE...\n${BACK}"
    dlg053="${GREEN}\nDownload di QB64PE e InForm...${BACK}\n"
    dlg054="${GREEN}Disimballaggio di QB64PE e InForm...${BACK}"
    dlg055="${BLUE}Ora, solo due ultime domande:"
    dlg056="${BLUE}\nIl passo successivo è scaricare e installare QB64PE e tutte le dipendenze\nrilevanti necessarie per compilare QB64PE su $VENDOR $RELEASE.\n\nNel frattempo, tieni presente che questa installazione può durare fino\na 15 minuti a causa del time per scaricare, compilare e installare QB64PE.\n\nQuindi, la velocità di questa installazione dipende sia dalla potenza della tua\nmacchina che dal tuo intrenet larghezza di banda.\n"
     dlg057="${GREEN}Hai terminato lo script e non è stato fatto nulla sul tuo computer.\n\n${BLUE}Si prega di riavviare questo script quando ne avete bisogno.\n\nAddio.${BACK}$dlg000"
    dlg058="${GREEN}\nOK. Continuare l'installazione...${BACK}"
    dlg059="${BLUE}\nCiao ${GREEN}$MYUSERNAME${BLUE} usando i privilegi di ${RED}root${BLUE},\n\nOra, questo script installa ${GREEN}$QB64PEREV${BLUE} e tutto il dipendenze\nnecessarie in base alle specifiche di distribuzione.\n\nIl tuo OS è: ${RED}$SYSTEM $VENDOR $RELEASE${BLUE} con le seguenti caratteristiche:\n\n Nome:   ${RED}$DISTRONAME\n ${BLUE}Sapore: ${RED}$FLAVOR bits\n ${BLUE}Kernel: ${RED}$KERNEL\n\n${BLUE}Per impostazione predefinita:\n\n La cartella di installazione di QB64PE è: ${RED}$QB64PEFOLDER\n${BLUE} La cartella di installazione TEMP è:    ${RED}$TEMPFOLDER\n\n"
    dlg060="${RED}Scusa ma dopo ${BACK}9${RED}tentativi, non riesco a installare $SOURCE$FILE"
    dlg061="Vuoi riprovare subito: s/N (ritorno vuoto = No) ? : "
    dlg062="${GREEN}Nuovo tentativo di download $SOURCE$FILE"
    dlg063="${RED}Questo script non può continuare senza $FILE2\n\n\${GREEN}Verifica la tua connessione Internet e riavvia lo script.\n\nSe il problema persiste, installa manualmente $FILE e segnalalo a admin@as2.com\n\n${BLUE}Addio.${BACK}$dlg000"
    dlg064="${RED}\nScusa ma dopo ${BACK} 5 ${RED}tentativi, non riesco a installare $FILE"
    dlg065="Vuoi riprovare subito: s/N (ritorno vuoto = No)? : "
    dlg066="${GREEN}Nuovo tentativo di installazione $FILE"
    dlg067="${RED}Scusa ma questo script non può continuare senza $FILE\n\n${GREEN}Verifica la tua connessione Internet e riavvia lo script.\n${BLUE}Addio${BACK}$dlg000"
    dlg068="\n${BLUE}Hello $ME,${RED}\n\nÈ necessario installare lsb_release per utilizzare questo script."
    dlg069="Vuoi installare lsb_release adesso: S/n (ritorno vuoto = Sì) ? "
    dlg070="\n${RED}Questo script non può continuare senza lsb_release.\n\n${GREEN}Installa lsb_release e riavvia lo script.\n\n${BLUE}Addio.${BACK}$dlg000"
    dlg071="${RED}Per favore, devi installare wget per usare questo script."
    dlg072="Vuoi installare wget ora: S/n (ritorno vuoto = Sì) ? "
    dlg073="${GREEN}Questo script non può continuare senza wget.\nPlease install wget and restart the script.\n\n${BLUE}Goodbye.${BACK}$dlg000"
    dlg074="\n${BLUE}Ciao $ME,\n\n${RED}È necessario utilizzare i privilegi di root per utilizzare questo script.\n\n${GREEN}Si prega di riavviare questo script usando${BACK} [sudo] ${GREEN}or ${BACK}[su] ${GREEN}or ${BACK}[su -]${GREEN} di\nconseguenza con la politica security del tuo sistema operativo.\n\n${BLUE}Addio.${BACK}\n\n--------------------------------------------------------------------------------\n"
    dlg075="${BLUE}\nThe script can backup your $QB64PEFOLDER into your /home/$MYUSERNAME/backup-qb64pe.${YELLOW}\n"
    dlg076="Do you want to backup your $QB64PEFOLDER Y/n (empty return = Yes )? "
    dlg077="${RED}\nOK, your $QB64PEFOLDER is not saved into /home/$MYUSERNAME/backup-qb64pe.${GREEN}\n\nPlease check what to do with your $QB64PEFOLDER folder (move or rename or delete \nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg078="${GREEN}\nOK, the script is saving your $QB64PEFOLDER into /home/$MYUSERNAME/backup-qb64pe"
    dlg079="${RED}\nWARNING! the directory /home/$MYUSERNAME/backup-qb64pe already exists!\n"
    dlg080="So, your current /opt/qb64pe foldder wasn't saved, yet.\n\n${BLUE}Please check what to do with your previous /home/$MYUSERNAME/backup-qb64pe folder\n(move or rename or delete \nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg081="\n${GREEN}Now, QB64PE was saved into /home/$MYUSERNAME/backup-qb64pe\n"
    dlg082="Are you ready to remove the previous $QB64PEFOLDER now: Y/n (empty return = Yes) ? "
    dlg083="\n${GREEN}You didn't reinstall QB64PE and InForm.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
    dlg099="${RED}Thanks for their times and tremandous advice helping me to make this script to:\n\nFrom the https://forum.ubuntu-fr.org community (by alphabetical order):\nAmiralgaby, Bousky, Clémentv, grim7reaper, epehj, hoper, Hizoka, MicP, nesthib,\npingouinux, The Uploader, tiramiseb, Watael and many others.\n\nFrom the https://forums.fedora-fr.org community (by alphabetical order): fgland,\nmadko, nouvo09, pingou, remi and many others.\n\nFrom the http://www.manjaro.fr community (by alphabetical order): ewolnux,\nlemust83, loubrix, papajoke, patri-arch, smurf, waitnsea and many others.\n\nFrom the https://www.centos.org community (by alphabetical order): bob, Emma,\nMartinR, stevemowbray, TrevorH and many others.\n\nFrom the https://ubuntuforums.org community (by alphabetical order): steeldriver\nand many others.\n\nFrom the https://qb64phoenix.com/forum/index.php community: Donald, doppler,\nFlukiluke and many others.\n\nSpecial thanks to Fellippe Heitor for his open source project InForm."
}
# --------------------------------------------------------------------------------
#
# set the dialog messages in french
#
set_language_fr()
{
    dlg000="${BACK}\n--------------------------------------------------------------------------------\n"
    dlg001="Merci d'appuyer sur la touche [Entrée] pour continuer..."
    dlg002="${BLUE}\nHello ${GREEN}$ME${BLUE},\n\nCe script installe (et désinstalle) ${RED}$QB64PEREV${BLUE}\n et l'excellent ${RED}InForm GDE $INFORMREV${BLUE} de ${RED}Fellippe Heitor.${BLUE}\n\nCe script ${RED}$SCRIPTREV${BLUE} va afficher des messages avec des couleurs.\n\n- en bleu:   information de ce qui va être fait par ce script\n\n${YELLOW}- en jaune:  question à laquelle vous devez répondre pour continuer le script\n\n${RED}- en rouge:  problème avec votre réponse à la question posée précédemment\n\n${GREEN}- en vert:   acceptation de votre réponse\n\n${BACK}- en blanc:  action importante faite sur votre système.\n\n"
    dlg003="\n${GREEN}OK, le nom d'utilisateur${RED} $MYUSERNAME ${GREEN}est valide sur ce système."
    dlg004="\n${GREEN}Désolé, le nom d'utilisateur${RED} $MYUSERNAME ${GREEN}n'est pas autorisé sur ce système .\n\n${BLUE}Merci de réessayer."
    dlg005="Merci de saisir votre nom d'utilisateur pour continuer : ? "
    dlg006="\n${GREEN}Votre nom d'utilisateur est vide .\n"
    dlg007="Voulez-vous saisir votre nom pour continuer O/n : (retour vide = Oui)? "
    dlg008="\n${RED}Désolé, ce script ne peut pas continuer sans votre nom d'utilisateur.${BLUE}\n\nAu revoir.\n${BACK}$dlg000"
    dlg009="${BLUE}Bonjour ${GREEN}$ME,"
    dlg010="\n${RED}ATTENTION\n---------\n"
    dlg011="${RED}Ce script ne peut pas continuer sans les privilèges root (ex: ${BACK} [sudo]${RED} ou ${BACK}[su]${RED}ou ${BACK}[su -]${RED}).\n\n${GREEN}Merci de relancer ce script par la commande : ${BACK}[sudo ./QB64PE_install.sh]${GREEN} ou lancez\nune session ${RED}root${GREEN} par ${BACK}[su]${GREEN} ou ${BACK}[su -]${GREEN}, puis lancez ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Au revoir.\n${BACK}$dlg000\n"
    dlg012="${RED}Ce script ne peut pas continuer sans les privilèges root (${BACK}[sudo]${RED} ou ${BACK}[su]${RED} ou ${BACK}[su -]${RED}).\n\n${GREEN}Merci de lancer une ${RED}session root${GREEN} par ${BACK}[su]${GREEN} ou par ${RED}([su -])${GREEN} ensuite\n allez dans le dossier contenant ce script et lancer ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Au revoir.\n${BACK}$dlg000\n"
    dlg013="\n${RED}ATTENTION\n---------\n\n${GREEN}Vous utilisez les privilèges du compte ${RED}root${GREEN}.\n\nMais je ne peux pas deviner votre ${RED}nom d'utilisateur${GREEN} et ce script a besoin\nde cette information pour continuer.\n"
    dlg014="${BACK}Suppression du précédent dossier QB64PE.${BACK}"
    dlg015="${BACK}\nSuppression du précédent dossier d'installation temporaire.${BACK}"
    dlg016="${BACK}\nSuppression de l'icône QB64PE IDE du bureau.${BACK}"
    dlg016b="${BACK}\nSuppression de l'icône InForm GDE du bureau.${BACK}"
    dlg016d="${BACK}\nSuppression du lien QB64PE du bureau.${BACK}"
    dlg017="${BACK}\nSuppression du chemin QB64PE et du fichier qb64pe.bash de lancement.${BACK}"
    dlg018="${BACK}\nSuppression de l'entrée QB64PE IDE du menu application.${BACK}"
    dlg018b="${BACK}\nSuppression de l'entrée InForm GDE du menu application.${BACK}"
    dlg019="\n${GREEN}QB64PE & InForm ont été supprimés de votre machine.\n\n${BLUE}Maintenant, prêt pour une nouvelle installation."
    dlg019b="Voulez-vous réinstaller QB64PE et InForm O/n (retour vide = Oui)? : "
    dlg019c="\n${GREEN}Vous n'avez pas réinstallé QB64PE et InForm.\n${BLUE}\nMerci de réessayer quand vous serez prêt.\n\nAu revoir.\n${BACK}$dlg000\n"
    dlg020="Etes-vous prêts à désinstaller QB64PE O/n (retour vide = Oui)? : "
    dlg021="\n${GREEN}Ok, prêt pour la désinstallation de QB64PE.\n"
    dlg022="\n${GREEN}Ok, QB64PE vas être désinstallé puis réinstallé.\n\n${BLUE}Cependant avant de le faire, vous pouvez vouloir faire une sauvegarde de vos\nsources (.bas).\n\nSi c'est le cas, faites une pause et faites vos sauvegardes, puis continuez."
    dlg022b="\n${GREEN}Ok, QB64PE vas être désinstallé puis réinstallé."
    dlg023="\n${BLUE}Hé ${GREEN}$MYUSERNAME${BLUE} utilisant les${RED} privilèges root${BLUE},"
    dlg024="\n${BLUE}Désolé mais comme dit précédemment :"
    dlg025="\n${GREEN}QB64PE a déjà été installé sur cette machine avec le script QB64PE_install.sh\net n'a pas été désinstallé complètement en laissant des fichiers inutiles.\n"
    dlg026="${RED}Aussi, il n'est pas possible de réinstaller QB64PE maintenant."
    dlg027="Voulez-vous désinstaller QB64PE avant de le réinstaller O/n (retour vide = Oui)? "
    dlg028="${GREEN}\nMerci de désinstaller QB64PE avant de le réinstaller.\n\n${BLUE}Au revoir.${BACK}$dlg000\n"
    dlg029="\n${GREEN}Vous n'avez pas installé QB64PE.\n${BLUE}\nMerci de réessayer quand vous serez prêt.\n\nAu revoir.\n${BACK}$dlg000\n"
    dlg030="\n${GREEN}L'installation de QB64PE démarre. Merci d'être patient...\n"
    dlg031="${BLUE}\nOK, tout est prêt."
    dlg032="Etes-vous prêts à installer QB64PE & InForm: O/n (retour vide = Oui) ? "
    dlg033="${GREEN}OK, il n'y aura qu'une entrée dans le menu application.${BACK}\n"
    dlg034="${GREEN}OK, il y aura des icônes starter sur le bureau et des entrées dans le menu.${BACK}\n"
    dlg035="Voulez-vous des icônes starter sur votre bureau: O/n (retour vide = Oui)? "
    dlg036="${GREEN}Bien, le dossier $TEMPFOLDER sera supprimé.${BACK}"
    dlg037="${GREEN}OK, le dossier $TEMPFOLDER ne sera pas supprimé.${BACK}"
    dlg038="${YELLOW}A la fin du script, voulez-vous conserver le dossier $TEMPFOLDER pour voir ce"
    dlg039="qui a été fait pendant l'installation: o/N (retour vide = Non)?"
    dlg040="${GREEN}\nCréation de la librarie LibQB...\n${BACK}"
    dlg041="${GREEN}Création de la librarie FreeType...\n${BACK}"
    dlg042="${GREEN}Création des User Additions...\n${BACK}"
    dlg043="${GREEN}Création de la librarie Core:FreeGLUT...\n${BACK}"
    dlg044="${GREEN}Préparation de QB64PE...\n${BACK}"
    dlg045="${GREEN}\nCompilation de QB64PE...\n${BACK}"
    dlg045b="${RED}QB64PE a été créé.\n${BACK}"
    dlg045c="${GREEN}Maintenant compilation de InForm avec le nouveau compilateur QB64PE...\n${BACK}"
    dlg045d="${RED}\nInForm a été créé.\n${BACK}"
    dlg046="${GREEN}Installation de QB64PE et InForm...\n${BACK}"
    dlg047="${GREEN}\nL'installation est terminée.\n\n${RED}Maintenant, vous pouvez enfin exécuter QB64PE à partir de n'importe quelle\n session de terminal sans être dans le répertoire de QB64PE\ncomme vous le feriez avec GCC en tapant simplement 'qb64pe' ou en lançant\nla ligne de commande de compilation 'qb64pe -x source_file.bas -o exécutable_file'\net éventuellement en ajoutant les répertoires source et  destination.\nqb64pe -x /source_directory/source_file.bas -o /destination_directory/exécutable_file\n"
    dlg048="${GREEN}Suppression de $TEMPFOLDER.\n${BACK}"
    dlg048b="${RED}Vous avez toujours le dossier $TEMPFOLDER pour voir ce que le script a fait.\n${BACK}"
    dlg049="${RED}\nMalheureusement, il apparaît que la création de l'exécutable QB64PE a échouée.\n\n${GREEN}Ceci est une indcation d'une erreur de compilation et vous avez du voir de nombreux\nmessages d'erreur à l'écran.\n\nD'habitude, cela est du à des packages manquants pour la compilation.\n\nSi vous avez beoins d'aide, merci de passer un message sur le forum QB64PE\nou d'envoyer un e-mail à : admin@as2.com\n\nMerci de détailler ce qui c'est passé et d'indiquer la distribution utilisée avec les \ncommandes de la ligne suivante :\n\n${BACK}lsb_release -sd && lsb_release -sc && lsb_release -sr && uname -r\n"
    dlg050="${BLUE}Désolé pour cet inconvénient.\n\nAu revoir.\n${BACK}$dlg000\n"
    dlg051="${BLUE}Merci d'avoir utilisé le script QB64PE_install.sh\n\n${RED}Pour désinstaller QB64PE & InForm-e, juste relancez le script.\n\n${BLUE}Au revoir.\n${BACK}$dlg000\n"
    dlg052="${GREEN}\nVérifie et si non présentes installe les dépendences nécessaires pour\ncompiler QB64PE...\n${BACK}"
    dlg053="${GREEN}\nTélécharge QB64PE et InForm...${BACK}\n"
    dlg054="${GREEN}Décompacte QB64PE...${BACK}"
    dlg055="${BLUE}Maintenant, juste deux dernières questions :"
    dlg056="${BLUE}\n\nLa prochaine étape est de télécharger et d'installer QB64PE et les dépendences\nnécessaires pour compiler QB64PE sous $VENDOR $RELEASE.\n\nCependant, soyez avertis que cette installation peut demander jusqu'à 15 minutes\nen raison du temps pour télécharger, compiler et installer QB64PE.\n\nLa vitesse d'installation dépend de la puissance de votre machine et du débit de\nvotre connexion Internet.\n"
    dlg057="${GREEN}Vous avez arrêté ce script et rien n'a été fait sur votre machine.\n\n${BLUE}Veuillez relancer ce script quand vous en aurez besoin.\n\nAu revoir.${BACK}$dlg000"
    dlg058="${GREEN}\nOK. L'installation continue...${BACK}"
    dlg059="${BLUE}\nBonjour ${GREEN}$MYUSERNAME${BLUE} utilisant les${RED} privilèges root${BLUE},\n\nMaintenant, ce script va installer ${GREEN}$QB64PEREV${BLUE} et les dépendances\nnécessaires en accord avec les spécifications de votre distribution.\n\nVotre OS est : ${RED}$SYSTEM $VENDOR $RELEASE${BLUE} avec les charactéristiques suivantes :\n\n Nom :    ${RED}$DISTRONAME\n ${BLUE}Version: ${RED}$FLAVOR bits\n ${BLUE}Kernel:  ${RED}$KERNEL\n\n${BLUE}Par défaut :\n\n Le dossier de QB64PE sera :  ${RED}$QB64PEFOLDER\n${BLUE} Le dossier temporaire sera : ${RED}$TEMPFOLDER\n\n"
    dlg060="${RED}Désolé mais après ${BACK}9${RED} éssais, je ne peux pas télécharger $SOURCE$FILE"
    dlg061="Voulez-vous réessayer maintenant : o/N (retour vide = Non) ? : "
    dlg062="${GREEN}Tentative de téléchargement de $SOURCE$FILE"
    dlg063="${RED}Ce script ne peut pas continuer sans $FILE2\n\n\${GREEN}Merci de vérifier votre connexion Internet connexion et de relancer ce script.\n\nSi le problème persiste, merci d'installer $FILE manuellement et de le signaler à admin@as2.com\n\n${BLUE}Au revoir.${BACK}$dlg000"
    dlg064="${RED}\nDésolé, mais après ${BACK}5${RED} tentatives, je ne peux pas obtenir $PACKET"
    dlg065="Voulez-vous réessayer maintenant : o/N (retour vide = Non)? : "
    dlg066="${GREEN}Nouvelle tentative d'obtenir $PACKET"
    dlg067="${RED}Désolé mais ce script ne peut pas continuer sans $PACKET\n\n${GREEN}Merci de vérifier votre connexion Internet and de relancer ce scipt.\n${BLUE}Au revoir${BACK}$dlg000"
    dlg068="\n${BLUE}Bonjour $ME,${RED}\n\nVous devez installer lsb_release pour utiliser ce script."
    dlg069="Voulez-vous installer lsb_release maintenant : O/n (retour vide = Oui) ? "
    dlg070="\n${RED}Ce script ne peut pas continuer sans lsb_release.\n\n${GREEN}Merci d'installer lsb_release et de relancer ce script.\n\n${BLUE}Au revoir.${BACK}$dlg000"
    dlg071="${RED}Désolé, vous DEVEZ installer [wget] pour utiliser ce script."
    dlg072="Voulez-vous installer wget maintenant : O/n (retour vide = Oui) ? "
    dlg073="${GREEN}Ce script ne peut pas continuer sans [wget].\nMerci d'installer wget et de relancer ce script.\n\n${BLUE}Au revoir.${BACK}$dlg000"
    dlg074="\n${BLUE}Bonjour $ME,\n\n${RED}Vous devez utiliser les privilèges root pour utiliser ce script.\n\n${GREEN}Merci de relancer ce script avec${BACK} [sudo] ${GREEN}ou${BACK} [su] ${GREEN}ou${BACK} [su -]${GREEN} en fonction de la\npolitique de sécurité de votre OS.\n\n${BLUE}Au revoir.${BACK}\n\n--------------------------------------------------------------------------------\n"
    dlg075="${BLUE}\nLe script peut sauver $QB64PEFOLDER dans /home/$MYUSERNAME/backup-qb64pe.${YELLOW}\n"
    dlg076="Voulez-vous sauver votre $QB64PEFOLDER O/n (retour vide = Oui )? "
    dlg077="${RED}\nOK, votre $QB64PEFOLDER n'est pas sauvé dans /home/$MYUSERNAME/backup-qb64pe.${GREEN}\n\nMerci de voir que faire de votre dossier $QB64PEFOLDER (move or rename or delete \nit) et reslancer le script quand vous serez prêt.\n\n${BLUE}Au revoir.\n${BACK}$dlg000\n"
    dlg078="${GREEN}\nOK, le script sauve $QB64PEFOLDER dans /home/$MYUSERNAME/backup-qb64pe."
    dlg079="${RED}\nWARNING! le répertoire /home/$MYUSERNAME/backup-qb64pe existe déjà.\n"
    dlg080="Donc, votre dossier /opt/qb64pe n'a pas été encore sauvé.\n\n${BLUE}Merci de voir que faire de votre dossier /home/$MYUSERNAME/backup-qb64pe\n(move or rename or delete it) et relancez le script quand vous serez prêt.\n\n${BLUE}Au revoir.\n${BACK}$dlg000\n"
    dlg081="\n${GREEN}Votre dossier $QB64PEFOLDER est sauvé dans /home/$MYUSERNAME/backup-qb64pe\n"
    dlg082="Etes-vous prêt à supprimer votre dossier $QB64PEFOLDER maintenant: O/n (retour vide = Oui) ? "
    dlg083="\n${GREEN}Vous n'avez pas réinstallé QB64PE et InForm.\n${BLUE}\nMerci de recommencer quand vous serez prêt.\n\nAu revoir.\n${BACK}$dlg000\n"
    dlg099="${RED}Thanks for their times and tremandous advice helping me to make this script to:\n\nFrom the https://forum.ubuntu-fr.org community (by alphabetical order):\nAmiralgaby, Bousky, Clémentv, grim7reaper, epehj, hoper, Hizoka, MicP, nesthib,\npingouinux, The Uploader, tiramiseb, Watael and many others.\n\nFrom the https://forums.fedora-fr.org community (by alphabetical order): fgland,\nmadko, nouvo09, pingou, remi and many others.\n\nFrom the http://www.manjaro.fr community (by alphabetical order): ewolnux,\nlemust83, loubrix, papajoke, patri-arch, smurf, waitnsea and many others.\n\nFrom the https://www.centos.org community (by alphabetical order): bob, Emma,\nMartinR, stevemowbray, TrevorH and many others.\n\nFrom the https://ubuntuforums.org community (by alphabetical order): steeldriver\nand many others.\n\nFrom the https://qb64phoenix.com/forum/index.php community: Donald, doppler,\nFlukiluke and many others.\n\nSpecial thanks to Fellippe Heitor for his open source project InForm."
}
# --------------------------------------------------------------------------------
#
# set the dialog messages in russian
#
set_language_be()
{
    dlg000="${BACK}\n--------------------------------------------------------------------------------\n"
    dlg001="Пожалуйста, нажмите клавишу [Enter], чтобы продолжить..."
    dlg002="${BLUE}\nЗдравствуйте ${GREEN}$ME${BLUE},\n\nЭтот скрипт устанавливает (и удалений) ${RED}$QB64PEREV${BLUE}\nи отличный отладчик ${RED}InForm GDE $INFORMREV${BLUE} от ${RED}Fellippe Heitor.${BLUE}\n\nЭЭтот скрипт ${RED}$SCRIPTREV${BLUE} отображает сообщения с использованием разных цветов.\n\n- синий:    информация о том, что это будет сделано с помощью сценария\n\n${YELLOW}- желтый:   вопрос вы, чтобы ответить, чтобы продолжить выполнение сценария\n\n${RED}- красный:  важная информация или проблема с ответом на предыдущий вопрос\n\n${GREEN}- зеленый:  ответ или действие после вашего ответа\n\n${BACK}- белый:    важное действие сделано в вашей системе.\n\n"
    dlg003="\n${GREEN}OK, имя пользователя учетной записи${RED} $MYUSERNAME ${GREEN}действует в этой системе.\n\n${BLUE}Пожалуйста, повторите попытку."
    dlg005="Введите имя учетной записи пользователя, чтобы продолжить: ? "
    dlg006="\n${GREEN}Ваше имя учетной записи пользователя пуста.\n"
    dlg007="Вы хотите, чтобы ввести имя пользователя для продолжения: д/n (пустой возврат = Да)? "
    dlg008="\n${RED}К сожалению, этот сценарий не может продолжаться, не зная имя пользователя.${BLUE}\n\nПрощай.\n${BACK}$dlg000"
    dlg009="${BLUE}Здравствуйте ${GREEN}$ME,"
    dlg010="\n${RED}ПРЕДУПРЕЖДЕНИЕ\n--------------\n"
    dlg011="${RED}К сожалению, этот сценарий не может продолжаться, не зная имя пользователя. (то есть${BACK} [sudo]${RED} ОУ ${BACK}[su]${RED} ОУ ${BACK}[su -]${RED}).\n\n${GREEN}Пожалуйста, перезапустите скрипт с командой: ${BACK}[sudo ./QB64PE_install.sh]${GREEN} ОУ начать\n${RED}root сессия${GREEN} \nс помощью ${BACK}[su]${GREEN} ОУ ${BACK}[su -]${GREEN}, затем начать ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Прощай.\n${BACK}$dlg000\n"
    dlg012="${RED}Этот сценарий не может быть использована без root привилегий. (${BACK}[su -]${RED}).\n\n${GREEN}Пожалуйста, начните с $ {RED} root сессии ${GREEN}, используя ${BACK}[su]${GREEN} ОУ ${RED}([su -])${GREEN} затем Гото папку, в которой вы установили этот сценарий и начать ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Прощай.\n${BACK}$dlg000\n"
    dlg013="\n${RED}ПРЕДУПРЕЖДЕНИЕ\n--------------\n\n${GREEN}Вы используете ${RED}root${GREEN} счета привилегированности.\n\nТаким образом, я не могу догадаться, ${RED}ваш реальный счет имя пользователя${GREEN} и этот\nсценарий нуждается в этой информации для продолжения.\n"
    dlg014="${BACK}Удаление предыдущей папки Qb64.${BACK}"
    dlg015="${BACK}\nУдаление предыдущей временной установки папку.${BACK}"
    dlg016="${BACK}\nУдаление значка стартовой клавиатуры QB64PE IDE.${BACK}"
    dlg016b="${BACK}\nУдаление значка стартовой клавиатуры InForm GDE.${BACK}"
    dlg016d="${BACK}\nУдаление значка стартовой клавиатуры QB64PE link.${BACK}"
    dlg017="${BACK}\nУдаление пути Qb64 и баш стартовый файл.${BACK}"
    dlg018="${BACK}\nУдаление записи меню Qb64 IDE.${BACK}"
    dlg018b="${BACK}\nУдаление записи меню InForm GDE.${BACK}"
    dlg019="\n${GREEN}Qb64 был аккуратно удален с вашего компьютера.\n\n${BLUE}Теперь мы готовы начать новый процесс установки."
    dlg019b="Вы хотите переустановить QB64PE & InForm: Д/Н (пустой возврат = Да)? "
    dlg019c="\n${GREEN}Вы не переустанавливали QB64PE & InForm.\n${BLUE}\nПовторите попытку, когда вы будете готовы.\n\nПрощай.\n${BACK}$dlg000\n"
    dlg020="Вы не готовы к удалению Qb64 Д/Н (пустой возврат = Да)? : "
    dlg021="\n${GREEN}Хорошо, мы будем аккуратно удалить Qb64.\n"
    dlg022="\n${GREEN}Хорошо, Qb64 собирается быть аккуратно удалены с вашего компьютера затем переустановить.\n\n${BLUE}Тем не менее, прежде чем процесс, возможно, потребуется сделать резервную копию ваших источников файлов (.bas).\n\nЕсли это так, пожалуйста, держите этот сценарий и сделать резервную копию, а затем продолжить."
    dlg022b="\n${GREEN}Хорошо, Qb64 собирается быть аккуратно удалены с вашего компьютера затем переустановить."
    dlg024="\n${BLUE}Извините, но как уже было сказано:"
    dlg025="\n${GREEN}Qb64 уже была установлена ​​на вашем компьютере с QB64PE_install.sh сценарий и не\nбыл чисто удален с вашего компьютера оставляя ненужные файлы.\n"
    dlg026="${RED}Таким образом, это не представляется возможным установить его заново сразу."
    dlg027="Вы хотите, чтобы удалить QB64PE перед переустановкой Д/Н (пустой возврат = Да)? "
    dlg028="${GREEN}\nПожалуйста, удалите QB64PE перед тем, чтобы установить его снова.\n\n${BLUE}Прощай.${BACK}$dlg000\n"
    dlg029="\n${GREEN}Вы не установили QB64PE.\n${BLUE}\nПожалуйста, повторите попытку, когда вы будете готовы.\n\nПрощай.\n${BACK}$dlg000\n"
    dlg030="\n${GREEN}Начнется установка QB64PE. Пожалуйста, будьте терпеливы...\n"
    dlg031="${BLUE}\nВы все готово."
    dlg032="Вы готовы к установке QB64PE & InForm: Д/Н (пустой возврат = Да) ? "
    dlg033="${GREEN}ОК, будет только запись в меню приложения.${BACK}\n"
    dlg034="${GREEN}Ну, у вас будут значки на рабочем столе и записи в меню.${BACK}\n"
    dlg035="Вы хотите поставить стартер на рабочем столе: Д/Н (пустой возврат = Да)? "
    dlg036="${GREEN}Ну, папка $TEMPFOLDER будут удалены.${BACK}"
    dlg037="${GREEN}OK, папка $TEMPFOLDER не будут удалены.${BACK}"
    dlg038="${YELLOW}В конце сценария, вы хотите, чтобы держать папку $TEMPFOLDER чтобы проверить,"
    dlg039="что было сделано во время установки: Д/Н (пустой возврат = Нет)? "
    dlg040="${GREEN}\nЗдание library LibQB...\n${BACK}"
    dlg041="${GREEN}Здание library FreeType...\n${BACK}"
    dlg042="${GREEN}Здание User Additions...\n${BACK}"
    dlg043="${GREEN}Здание library Core:FreeGLUT...\n${BACK}"
    dlg044="${GREEN}Здание QB64PE...\n${BACK}"
    dlg045="${GREEN}\nсоставление QB64PE...\n${BACK}"
    dlg045b="${RED}Был создан QB64PE.\n${BACK}"
    dlg045c="${GREEN}составление InForm...\n${BACK}"
    dlg045d="${RED}\nБыл создан InForm.\n${BACK}"
    dlg046="${GREEN}Установка QB64PE & InForm...\n${BACK}"
    dlg047="${GREEN}\nУстановка завершена.\n${RED}Теперь вы, наконец, можете запустить QB64PE из любого сеанса терминала, не находясь в каталоге QB64PE,\nкак если бы вы использовали GCC, просто набрав «qb64pe» или запустив командную строку компиляции\n«qb64pe -x исходный_файл.bas -o исполняемый_файл» и, возможно, добавив источник и место назначения. каталоги.\nqb64pe -x /source_directory/source_file.bas -o /destination_directory/executable_file\n"
    dlg048="${GREEN}Удаление $TEMPFOLDER.\n${BACK}"
    dlg048b="${RED}You still have the $TEMPFOLDER folder to check what the script did.\n${BACK}"
    dlg049="${RED}\nК сожалению, создается впечатление, что QB64PE исполняемый файл не был создан.\n\n${GREEN}Это, как правило, признак сбоя компиляции и вы, наверное, видели\nмного сообщений об ошибках во всплывающем окне на экране.\n\nКак правило, это из-за недостающих пакетов, необходимых для компиляции.\n\nЕсли вам нужна помощь, пожалуйста, не стесняйтесь размещать на QB64PE форуме или по электронной почте мне по адресу: admin@as2.com\n\nПросьба подробно описать, что произошло и распределение вы используете три команды, следующей строки:\n\n${BACK}lsb_release -sd && lsb_release -sc && lsb_release -sr\n && uname -r"
    dlg050="${BLUE}Приносим извинения за неудобства.\n\nПрощай.\n${BACK}$dlg000\n"
    dlg051="${BLUE}Благодарим Вас за использование сценария QB64PE_install.sh.\n\n${RED}To safely uninstall QB64PE & InForm-pe, just restart the script.\n\n${BLUE}Всего наилучшего.\n${BACK}$dlg000\n"
    dlg052="${GREEN}\nПроверьте и, если нет установки зависимостей, необходимые для компиляции QB64PE...\n${BACK}"
    dlg053="${GREEN}\nзагрузка QB64PE & InForm...${BACK}\n"
    dlg054="${GREEN}Распаковка QB64PE...${BACK}"
    dlg055="${BLUE}Теперь, всего за два последних вопроса:"
    dlg056="${BLUE}\n\nон следующий шаг должен загрузить и установить Qb64, а также всех зависимостей\nРелевент, необходимых для компиляции Qb64 на $VENDOR $RELEASE.\n\nВ то же время, имейте в виду, что эта установка может длиться до 15 минут из-за\nвремени, чтобы загрузить, собрать и установить QB64PE.\n\nТаким образом, скорость этой установки зависит как от мощности вашей машины и\nвашего интренет полосой пропускания.\n"
    dlg057="${GREEN}Вы закончили сценарий, и ничего не было сделано на вашем компьютере.\n\n${BLUE}Пожалуйста, перезапустите этот сценарий, когда вам это нужно.\n\nПрощай.${BACK}$dlg000"
    dlg058="${GREEN}\nОК. Продолжая установку...${BACK}"
    dlg059="${BLUE}\nдравствуйте, ${GREEN}$MYUSERNAME${BLUE} с помощью ${RED}корень привилегированности${BLUE},\n\nТеперь этот скрипт устанавливает ${GREEN}$QB64PEREV${BLUE} а также\nвсе необходимые зависимости соответственно вашим спецификациям распределения.\n\nYВаша система:: ${RED}$SYSTEM $VENDOR $RELEASE${BLUE} со следующими характеристиками:\n\n имя:  ${RED}$DISTRONAME\n ${BLUE}вкус: ${RED}$FLAVOR bits\n ${BLUE}ядро: ${RED}$KERNEL\n\n${BLUE}По умолчанию:\n\n The Qb64 установить папки: ${RED}$QB64PEFOLDER\n${BLUE} ТЕМП установки папки: ${RED}$TEMPFOLDER\n\n"
    dlg060="${RED}Извините, но после того, как ${BACK}9${RED} попыток, я не могу скачать $SOURCE$FILE"
    dlg061="Вы хотите, чтобы повторить попытку прямо сейчас: Д/Н (пустой возврат = Нет) ? : "
    dlg062="${GREEN}Повторная попытка загрузить $SOURCE$FILE"
    dlg063="${RED}Этот сценарий не может продолжаться без $FILE2\n\n\${GREEN}Пожалуйста, проверьте подключение к Интернету и перезапустить скрипт.\n\Если проблема не устранена, необходимо установить $FILE вручную и repport его admin@as2.com\n\n${BLUE}Прощай.${BACK}$dlg000"
    dlg064="${RED}\nИзвините, но после того,${BACK} как 5 ${RED} попыток, я не могу установить $PACKET"
    dlg065="DВы хотите, чтобы повторить попытку прямо сейчас: Д/Н (пустой возврат = Нет)? : "
    dlg066="${GREEN}Повторная попытка установить $PACKET"
    dlg067="${RED}Извините, но этот сценарий не может продолжаться без $PACKET\n\n${GREEN}Пожалуйста, проверьте подключение к Интернету и перезапустить скрипт.\n${BLUE}Goodbye${BACK}$dlg000"
    dlg068="\n${BLUE}Здравствуйте $ME,${RED}\n\nНеобходимо установить lsb_release использовать этот сценарий."
    dlg069="Вы хотите установить lsb_release прямо сейчас: Д/Н (пустой возврат = Да) ? "
    dlg070="\n${RED}Этот сценарий не может продолжаться без lsb_release.\n\n${GREEN}Пожалуйста, установите lsb_release и перезапустить скрипт.\n\n${BLUE}Прощай.${BACK}$dlg000"
    dlg071="${RED}Пожалуйста, вы должны установить wget, чтобы использовать этот сценарий."
    dlg072="Вы хотите установить wget прямо сейчас: Д/Н (пустой возврат = Да) ? "
    dlg073="${GREEN}Этот сценарий не может продолжаться без wget.\nПожалуйста, установите wget и перезапустить скрипт.\n\n${BLUE}Прощай.${BACK}$dlg000"
    dlg074="\n${BLUE}Здравствуйте $ME,\n\n${RED}Вы должны использовать root привилегированности использовать этот сценарий.\n\n${GREEN}Пожалуйста, перезапустите этот скрипт, используя${BACK} [sudo] ${GREEN}или ${BACK}[su] ${GREEN}или ${BACK}[su -]${GREEN}\nсоответственно с политикой безопасности вашей системы.\n\n${BLUE}Прощай.${BACK}\n\n--------------------------------------------------------------------------------\n"
    dlg075="${BLUE}\nThe script can backup your $QB64PEFOLDER into your /home/$MYUSERNAME/backup-qb64pe.${YELLOW}\n"
    dlg076="Do you want to backup your $QB64PEFOLDER Y/n (empty return = Yes )? "
    dlg077="${RED}\nOK, your $QB64PEFOLDER is not saved into /home/$MYUSERNAME/backup-qb64pe.${GREEN}\n\nPlease check what to do with your $QB64PEFOLDER folder (move or rename or delete\nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg078="${GREEN}\nOK, the script is saving your $QB64PEFOLDER into /home/$MYUSERNAME/backup-qb64pe"
    dlg079="${RED}\nWARNING! the directory /home/$MYUSERNAME/backup-qb64pe already exists!\n"
    dlg080="So, your current /opt/qb64pe foldder wasn't saved, yet.\n\n${BLUE}Please check what to do with your previous /home/$MYUSERNAME/backup-qb64pe folder\n(move or rename or delete\nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg081="\n${GREEN}Now, QB64PE was saved into /home/$MYUSERNAME/backup-qb64pe\n"
    dlg082="Are you ready to remove the previous $QB64PEFOLDER now: Y/n (empty return = Yes) ? "
    dlg083="\n${GREEN}You didn't reinstall QB64PE and InForm.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
    dlg099="${RED}Thanks for their times and tremandous advice helping me to make this script to:\n\nFrom the https://forum.ubuntu-fr.org community (by alphabetical order):\nAmiralgaby, Bousky, Clémentv, grim7reaper, epehj, hoper, Hizoka, MicP, nesthib,\npingouinux, The Uploader, tiramiseb, Watael and many others.\n\nFrom the https://forums.fedora-fr.org community (by alphabetical order): fgland,\nmadko, nouvo09, pingou, remi and many others.\n\nFrom the http://www.manjaro.fr community (by alphabetical order): ewolnux,\nlemust83, loubrix, papajoke, patri-arch, smurf, waitnsea and many others.\n\nFrom the https://www.centos.org community (by alphabetical order): bob, Emma,\nMartinR, stevemowbray, TrevorH and many others.\n\nFrom the https://ubuntuforums.org community (by alphabetical order): steeldriver\nand many others.\n\nFrom the https://qb64phoenix.com/forum/index.php community: Donald, doppler,\nFlukiluke and many others.\n\nSpecial thanks to Fellippe Heitor for his open source project InForm."
}
# --------------------------------------------------------------------------------
#
# set the dialog messages in german
#
set_language_de()
{
    dlg000="${BACK}\n--------------------------------------------------------------------------------\n"
    dlg001="Danke an [Enter] drücken, um fortzufahren..."
    dlg002="${BLUE}\nHallo ${GREEN}$ME${BLUE},\n\nDieses Skript installiert (und deinstalliert) ${RED}$QB64PEREV${BLUE}\nund der ausgezeichnete ${RED}InForm GDE $INFORMREV${BLUE} von ${RED}Fellippe Heitor.${BLUE}\n.\n\nDieses Skript ${RED}$SCRIPTREV${BLUE} zeigt Nachrichten in verschiedenen Farben an.\n\n- In blau: Informationen, was das Skript machen wird,\n\n${YELLOW}- In gelb: Frage, die du beantworten musst, um die Ausführung des Skripts\n           fortzusetzen,\n\n${RED}- In rot:  wichtige Info oder Problem mit einer Antwort auf die vorherige Frage,\n\n${GREEN}- In grün: Antwort Ihres Betriebssystems oder Aktion nach Ihrer Antwort,\n\n${BACK}- In weiß: wichtige Maßnahmen auf Ihrem System.\n\n"
    dlg003="\n${GREEN}OK, der Kontobenutzername ${RED}$MYUSERNAME ${GREEN}ist auf diesem System gültig."
    dlg004="\n${GREEN}Der Kontobenutzername ${RED} $MYUSERNAME ${GREEN}ist auf diesem System nicht zulässig.\n\n${BLUE}Bitte erneut versuchen."
    dlg005="Bitte geben Sie Ihren Benutzernamen ein, um fortzufahren:? "
    dlg006="\n${GREEN}Ihr Benutzername ist leer.\n"
    dlg007="Möchten Sie Ihren Benutzernamen eingeben: J/n (leer return = Ja)? "
    dlg008="\n${RED}Dieses Skript kann nicht fortgesetzt werden, ohne Ihren Benutzernamen zu kennen.${BLUE}\n\nAuf Wiedersehen.\n${BACK}$dlg000"
    dlg009="${BLUE}Hallo ${GREEN}$ME,"
    dlg010="\n${RED}WARNUNG\n-------\n"
    dlg011="${RED}Dieses Skript kann nicht ohne die Root-Berechtigungen verwendet werden(d.h.${BACK} [sudo]${RED} oder ${BACK}[su]${RED} oder ${BACK}[su -]${RED}).\n\n${GREEN}Bitte starten Sie das Skript erneut mit dem Befehl: ${BACK}[sudo ./QB64PE_install.sh]${GREEN} oder starten\nsie eine ${RED}root session${GREEN} \nmit ${BACK}[su]${GREEN} oder ${BACK}[su -]${GREEN}, dann starten ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Auf Wiedersehen..\n${BACK}$dlg000\n"
    dlg012="${RED}Dieses Skript kann nicht ohne die Root-Berechtigungen verwendet werden (${BACK}[su -]${RED}).\n\n${GREEN}Bitte starten Sie eine ${RED}root session${GREEN} mit ${BACK}[su]${GREEN} oder ${RED}[su -])${GREEN} und dann in den Ordner, den Sie installiert haben Dieses Skript und starten Sie ${BACK}[./ QB64PE_install.sh]\n\n${BLUE}Auf Wiedersehen..\n${BACK}$dlg000\n"
    dlg013="\n${RED}WARNUNG\n-------\n\n${GREEN}Sie verwenden die Berechtigungen ${RED} root ${GREEN}.\n\nSo kann ich nicht erraten ${RED}Ihr Konto Konto Benutzername ${GREEN}und dieses Skript\nbenötigt diese Informationen um fortzufahren.\n"
    dlg014="${BACK}Löschen des vorherigen QB64PE-Ordners.${BACK}"
    dlg015="${BACK}\nLöschen des vorherigen temporären Installationsordners.${BACK}"
    dlg016="${BACK}\nLöschen der QB64PE IDE Icon Starter-Desktop-Verknüpfung.${BACK}"
    dlg016b="${BACK}\nLöschen der InForm GDE Icon Starter-Desktop-Verknüpfung.${BACK}"
    dlg016d="${BACK}\nLöschen der QB64PE Link-Desktop-Verknüpfung.${BACK}"
    dlg017="${BACK}\nLöschen des QB64PE-Pfads und der bash-Startdatei.${BACK}"
    dlg018="${BACK}\nLöschen des QB64PE IDE-Menüeintrags.${BACK}"
    dlg018b="${BACK}\nLöschen des InForm GDE-Menüeintrags.${BACK}"
    dlg019="\n${GREEN}QB64PE wurde sauber von Ihrem Computer entfernt.\n\n${BLUE}Jetzt können wir einen neuen Installationsvorgang starten."
    dlg019b="Möchten Sie QB64PE & InForm neu installieren? /n (leer return = Ja)? : "
    dlg019c="\n${GREEN}Sie haben QB64PE & InForm nicht neu installiert.\n${BLUE}\nBitte versuchen Sie es erneut, wenn Sie fertig sind.\n\Auf Wiedersehen.\n${BACK}$dlg000\n"
    dlg020="Sind Sie bereit QB64PE zu deinstallieren J/n (leer return = Ja)? : "
    dlg021="\n${GREEN}Ok, wir werden QB64PE sauber deinstallieren.\n"
    dlg022="\n${GREEN}Ok, QB64PE wird sauber von Ihrem Computer entfernt und dann neu installiert werden.\n\n${BLUE}Bevor Sie jedoch verarbeiten, müssen Sie möglicherweise Ihre Quelldateien (.bas) sichern.\n\nWenn dies der Fall ist, halten Sie bitte dieses Skript und machen Sie Ihre Sicherung, dann weiter."
    dlg022b="\n${GREEN}Ok, QB64PE wird sauber von Ihrem Computer entfernt und dann neu installiert werden."
    dlg023="\n${BLUE}Hey${GREEN} $MYUSERNAME ${BLUE}mit den ${RED}Root-Berechtigungen${BLUE},"
    dlg024="\n${BLUE}Sorry, aber wie schon gesagt:"
    dlg025="\n${GREEN}QB64PE war bereits auf Ihrem Computer mit dem QB64PE_install.sh-Skript installiert und\nwurde nicht sauber von Ihrem Computer deinstalliert verlassen unerwünschte Dateien.\n"
    dlg026="${RED}So ist es nicht möglich, es sofort wieder installieren."
    dlg027="Möchten Sie vor der Neuinstallation die Deinstallation entfernen J/n (leer return = Ja)? "
    dlg028="${GREEN}\nBitte deinstallieren Sie QB64PE, bevor Sie es erneut installieren.\n\n${BLUE}Auf Wiedersehen..${BACK}$dlg000\n"
    dlg029="\n${GREEN}Sie haben QB64PE nicht installiert.\n${BLUE}\nBitte versuchen Sie es erneut, wenn Sie fertig sind.\n\nAuf Wiedersehen..\n${BACK}$dlg000\n"
    dlg030="\n${GREEN}Die QB64PE-Installation wird gestartet. Bitte haben Sie Geduld...\n"
    dlg031="${BLUE}\nDu bist ganz eingestellt."
    dlg032="Sind Sie bereit, QB64PE  & InForm zu installieren: J/n (leer return = Ja) ? "
    dlg033="${GREEN}OK, es erfolgt nur ein Eintrag im Anwendungsmenü.${BACK}\n"
    dlg034="${GREEN}Nun, Sie haben Icon-Starter auf Ihrem Desktop und Einträge im Menü.${BACK}\n"
    dlg035="Möchten Sie icon Starters auf Ihren Desktop legen: J/n (leer return=Ja)?"
    dlg036="${GREEN}Nun wird der Ordner $TEMPFOLDER gelöscht.${BACK}"
    dlg037="${GREEN}OK, der Ordner $TEMPFOLDER wird nicht gelöscht.${BACK}"
    dlg038="${YELLOW}Wollen Sie am Ende des Skripts den Ordner $TEMPFOLDER beibehalten um zu"
    dlg039="überprüfen, was während der Installation gemacht wurde: j/N (leer return=Nein)?"
    dlg040="${GREEN}Bibliothek erstellen LibQB...\n${BACK}"
    dlg041="${GREEN}Bibliothek erstellen FreeType...\n${BACK}"
    dlg042="${GREEN}Ertellen User Additions...\n${BACK}"
    dlg043="${GREEN}Bibliothek erstellen Core:FreeGLUT...\n${BACK}"
    dlg044="${GREEN}Erstellen QB64PE...\n${BACK}"
    dlg045="${GREEN}\nKompilieren QB64PE...\n${BACK}"
    dlg045b="${RED}QB64PE wurde erstellt.\n${BACK}"
    dlg045c="${GREEN}Jetzt InForm kompilieren...\n${BACK}"
    dlg045d="${RED}\nInForm wurde erstellt.\n${BACK}"
    dlg046="${GREEN}Installieren von QB64PE & InForm...\n${BACK}"
    dlg047="${GREEN}\nDie Installation ist abgeschlossen.\nJetzt können Sie QB64PE endlich von jeder Terminalsitzung aus ausführen, \nohne sich im QB64PE-Verzeichnis zu befinden, wie Sie es bei GCC tun würden, indem Sie einfach 'qb64pe'\neingeben oder die Kompilierungsbefehlszeile 'qb64pe -x source_file.bas -o executable_file' \nausführen und möglicherweise die Quelle und das Ziel hinzufügen Verzeichnisse.\nqb64pe -x /source_directory/source_file.bas -o /destination_directory/executable_file\n"
    dlg048="${GREEN}Entfernen $TEMPFOLDER.\n${BACK}"
    dlg048b="${RED}You still have the $TEMPFOLDER folder to check what the script did.\n${BACK}"
    dlg049="${RED}\nLeider scheint es, dass die qb64pe-Datei nicht erstellt wurde.\n\n${GREEN}Dies ist in der Regel ein Hinweis auf einen Fehler zu kompilieren und Sie\nwahrscheinlich sah eine Menge Fehlermeldungen Pop-up auf dem Bildschirm.\n\nNormalerweise sind diese auf fehlende Pakete für die Zusammenstellung benötigt.\n\nWenn Sie Hilfe benötigen, fühlen Sie bitte sich frei, auf dem QB64PE Forum bekannt zu geben\noder E-Mail mich an: admin@as2.com\n\nBitte beachten Sie, was passiert ist und die Verteilung Sie verwenden die \nBefehle der nächsten Zeile:\n\n${BACK}lsb_release -sd && lsb_release -sc && lsb_release -sr && uname -r\n"
    dlg050="${BLUE}Entschuldigen Sie die Unannehmlichkeiten.\n\nAuf Wiedersehen..\n${BACK}$dlg000\n"
    dlg051="${BLUE}Vielen Dank für die Verwendung des Skripts QB64PE_install.sh.\n\n${RED}To safely uninstall QB64PE & InForm-pe3, just restart the script.\n\n${BLUE}Alles Gute.\n${BACK}$dlg000\n"
    dlg052="${GREEN}\nÜberprüfen Sie und wenn nicht vorhanden installieren Sie die Abhängigkeiten, die benötigt werden\num QB64PE zu kompilieren...\n${BACK}"
    dlg053="${GREEN}\nHerunterladen QB64PE & InForm...${BACK}\n"
    dlg054="${GREEN}Auspacken QB64PE...${BACK}"
    dlg055="${BLUE}Nun, nur zwei letzte Fragen:"
    dlg056="${BLUE}\n\nDer nächste Schritt ist, QB64PE herunterzuladen und zu installieren sowie alle\nrelevanten Abhängigkeiten die benötigt werden, um QB64PE zu kompilieren auf\n$VENDOR $RELEASE.\n\nIn der Zwischenzeit sollten Sie sich bewusst sein, dass diese Installation bis\nzu 15 Minuten dauern kann da QB64PE heruntergeladen, kompiliert und installiert\nwerden muss.\n\nDie Geschwindigkeit dieser Installation hängt also sowohl von der Leistung der\nMaschine als auch von der intrenet-Bandbreite ab.\n"
    dlg057="${GREEN}Sie beendeten das Skript und nichts wurde auf Ihrem Computer getan.\n\n${BLUE}Bitte starten Sie dieses Skript neu, wenn Sie es benötigen.\n\nAuf Wiedersehen..${BACK}$dlg000"
    dlg058="${GREEN}\nFortsetzung der Installation...${BACK}"
    dlg059="${BLUE}\nHallo ${GREEN} $MYUSERNAME ${BLUE}mit den ${RED}Root-Berechtigungen${BLUE},\n\nDieses Skript installiert nun ${GREEN}$QB64PEREV${BLUE} sowie alle\nnotwendigen Abhängigkeiten entsprechend Ihren Verteilungsspezifikationen.\n\nIhr Betriebssystem ist: ${RED}$SYSTEM $VENDOR $RELEASE${BLUE} mit den folgenden Eigenschaften:\n\n Name:      ${RED}$DISTRONAME\n ${BLUE}Geschmack: ${RED}$FLAVOR bits\n ${BLUE}Kernel:    ${RED}$KERNEL\n\n${BLUE}Standardmäßig:\n\n Der QB64PE-Installationsordner ist: ${RED}$QB64PEFOLDER\n${BLUE} Der TEMP-Installationsordner ist: ${RED}$TEMPFOLDER\n\n"
    dlg060="${RED}Sorry, aber nachdem ${BACK}9${RED} versucht, kann ich $SOURCE $FILE nicht herunterladen"
    dlg061="Möchten Sie es erneut versuchen: j/N (leer return = Nein) ? : "
    dlg062="${GREEN}Wiederholen zum Herunterladen $SOURCE$FILE"
    dlg063="${RED}Dieses Skript kann ohne $FILE2 nicht fortgesetzt werden\n\n\${GREEN}Überprüfen Sie Ihre Internetverbindung und starten Sie das Skript neu.\n\nWenn das Problem weiterhin besteht, installieren Sie bitte $FILE manuell und melden Sie es an admin@as2.com\n\n${BLUE}Auf Wiedersehen..${BACK}$dlg000"
    dlg064="${RED}\nSorry, aber nachdem ${BACK}5${RED} versucht, kann ich $PACKET nicht installieren"
    dlg065="Möchten Sie es erneut versuchen: j/N (leer return = Nein)? : "
    dlg066="${GREEN}Wiederholen, um $PACKET zu installieren"
    dlg067="${RED}Sorry, aber dieses Skript kann nicht ohne $PACKET fortgesetzt werden\n\n${GREEN}Überprüfen Sie Ihre Internetverbindung und starten Sie das Skript neu.\n${BLUE}Auf Wiedersehen.${BACK}$dlg000"
    dlg068="\n${BLUE}Hallo $ME,${RED}\n\nSie müssen lsb_release installieren, um dieses Skript zu verwenden."
    dlg069="Möchten Sie lsb_release jetzt installieren: J/n (leer return = Ja) ? "
    dlg070="\n${RED}Dieses Skript kann ohne lsb_release nicht fortgesetzt werden.\n\n${GREEN}Bitte lsb_release installieren und das Skript neu starten.\n\n${BLUE}Auf Wiedersehen..${BACK}$dlg000"
    dlg071="${RED}Bitte installieren Sie wget, um dieses Skript zu verwenden."
    dlg072="Möchten Sie wget jetzt installieren: J/n (leer return = Ja) ? "
    dlg073="${GREEN}Dieses Skript kann nicht ohne wget fortgesetzt werden.\nInstallieren Sie wget und starten Sie das Skript neu.\n\n${BLUE}Auf Wiedersehen..${BACK}$dlg000"
    dlg074="\n${BLUE}Hallo $ME,\n\n${RED}Um dieses Skript zu verwenden, müssen Sie die Root-Berechtigungen verwenden.\n\n${GREEN}Starten Sie das Skript mithilfe von ${BACK}[sudo]${GREEN} oder ${BACK}[su]${GREEN} oder ${BACK}[su -]${GREEN} entsprechend\noder Sicherheitsrichtlinie Ihres Betriebssystems neu.\n\n${BLUE}Auf Wiedersehen..${BACK}\n\n--------------------------------------------------------------------------------\n"
    dlg075="${BLUE}\nThe script can backup your $QB64PEFOLDER into your /home/$MYUSERNAME/backup-qb64pe.${YELLOW}\n"
    dlg076="Do you want to backup your $QB64PEFOLDER Y/n (empty return = Yes )? "
    dlg077="${RED}\nOK, your $QB64PEFOLDER is not saved into /home/$MYUSERNAME/backup-qb64pe.${GREEN}\n\nPlease check what to do with your $QB64PEFOLDER folder (move or rename or delete\nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg078="${GREEN}\nOK, the script will save your $QB64PEFOLDER into your /home/$MYUSERNAME/backup-qb64pe."
    dlg079="${RED}\nWARNING! the directory /home/$MYUSERNAME/backup-qb64pe already exists!\n"
    dlg080="So, your current /opt/qb64pe foldder wasn't saved, yet.\n\n${BLUE}Please check what to do with your previous /home/$MYUSERNAME/backup-qb64pe folder\n(move or rename or delete\nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg081="\n${GREEN}Now, QB64PE is saved into /home/$MYUSERNAME/backup-qb64pe\n"
    dlg082="Are you ready to remove the previous $QB64PEFOLDER now: Y/n (empty return = Yes) ? "
    dlg083="\n${GREEN}You didn't reinstall QB64PE and InForm.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
    dlg099="${RED}Thanks for their times and tremandous advice helping me to make this script to:\n\nFrom the https://forum.ubuntu-fr.org community (by alphabetical order):\nAmiralgaby, Bousky, Clémentv, grim7reaper, epehj, hoper, Hizoka, MicP, nesthib,\npingouinux, The Uploader, tiramiseb, Watael and many others.\n\nFrom the https://forums.fedora-fr.org community (by alphabetical order): fgland,\nmadko, nouvo09, pingou, remi and many others.\n\nFrom the http://www.manjaro.fr community (by alphabetical order): ewolnux,\nlemust83, loubrix, papajoke, patri-arch, smurf, waitnsea and many others.\n\nFrom the https://www.centos.org community (by alphabetical order): bob, Emma,\nMartinR, stevemowbray, TrevorH and many others.\n\nFrom the https://ubuntuforums.org community (by alphabetical order): steeldriver\nand many others.\n\nFrom the https://qb64phoenix.com/forum/index.php community: Donald, doppler,\nFlukiluke and many others.\n\nSpecial thanks to Fellippe Heitor for his open source project InForm."
}
# --------------------------------------------------------------------------------
#
# set the dialog messages in portugese
#
set_language_pt()
{
    dlg000="${BACK}\n--------------------------------------------------------------------------------\n"
    dlg001="Por favor, aperte a tecla [Enter] para continuar..."
    dlg002="${BLUE}\nOlá ${GREEN}$ME${BLUE},\n\nEste script instala (e desinstala)${RED}$QB64PEREV${BLUE}\ne o excelente ${RED}InForm GDE $INFORMREV${BLUE} da ${RED}Fellippe Heitor.${BLUE}\n\nEste script ${RED}$SCRIPTREV${BLUE} exibirá mensagens usando cores diferentes.\n\n- Em azul:     informações sobre o que vai ser feito pelo script,\n\n${YELLOW}- Em amarelo:  pergunta que você precisa responder para continuar a execução do\n               script,\n\n${RED}- Em vermelho: informação importante ou problema com uma resposta à pergunta\n               anterior,\n\n${GREEN}- Em verde:    resposta do seu sistema operacional ou ação após sua resposta,\n\n${BACK}- Em branco:   ação importante feita em seu sistema.\n\n"
    dlg003="\n${GREEN}OK, o nome de usuário da conta${RED} $MYUSERNAME ${GREEN}é válido neste sistema."
    dlg004="\n${GREEN}Desculpe, o nome de usuário da conta${RED} $MYUSERNAME ${GREEN}não é permitido neste sistema.\n\n${BLUE}Tente novamente."
    dlg005="Digite o nome de usuário da sua conta para continuar: ? "
    dlg006="\n${GREEN}O nome de usuário da sua conta está vazio.\n"
    dlg007="Deseja inserir seu nome de usuário para continuar: S/n (Enter = Sim)? "
    dlg008="\n${RED}Desculpe, este script não pode continuar sem saber seu nome de usuário.${BLUE}\n\nAdeus.\n${BACK}$dlg000"
    dlg009="${BLUE}Olá ${GREEN}$ME,"
    dlg010="\n${RED}ATENÇÃO\n-------\n"
    dlg011="${RED}Este script não pode ser usado sem os privilégios de root (ou seja,${BACK} [sudo] ${RED}ou${BACK} [su] ${RED}ou${BACK} [su -]${RED}).\n\n${GREEN}Reinicie o script com o comando: ${BACK}[sudo ./QB64PE_install.sh]${GREEN} ou inicie uma sessão root usando ${BACK} [su] ${GREEN}ou${BACK} [su -]${GREEN}, então inicie ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Adeus.\n${BACK}$dlg000\n"
    dlg012="${RED}Este script não pode ser usado sem os privilégios de root (${BACK}[su -]${RED}).\n\n${GREEN}Inicie uma sessão root ${GREEN} usando${BACK} [su] ${GREEN}ou${RED} ([su -])${GREEN}\nentão vá para a pasta onde você instalou este script e inicie ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Adeus.\n${BACK}$dlg000\n"
    dlg013="\n${RED}ATENÇÃO\n-------\n\n${GREEN}Você está usando os privilégios de conta ${RED}root${GREEN}.\n\nEntão, eu não posso adivinhar ${RED}seu nome de usuário de conta real${GREEN} e este script\nprecisa dessas informações para continuar.\n"
    dlg014="${BACK}Excluindo a pasta anterior QB64PE.${BACK}"
    dlg015="${BACK}\nExcluindo a pasta de instalação temporária anterior.${BACK}"
    dlg016="${BACK}\nExcluindo o icone do desktop QB64PE IDE starter.${BACK}"
    dlg016b="${BACK}\nExcluindo o icone do desktop InForm GDE starter.${BACK}"
    dlg016d="${BACK}\nExcluindo o icone do desktop QB64PE link.${BACK}"
    dlg017="${BACK}\nExcluindo o caminho QB64PE e o arquivo inicial do bash.${BACK}"
    dlg018="${BACK}\nExcluindo a entrada do menu QB64PE IDE.${BACK}"
    dlg018b="${BACK}\nExcluindo a entrada do menu InForm GDE.${BACK}"
    dlg019="\n${GREEN}QB64PE foi removido do seu computador.\n\n${BLUE}Agora, estamos prontos para iniciar um novo processo de instalação."
    dlg019b="Deseja reinstalar QB64PE & InForm S/n (Enter = Sim)? : "
    dlg019c="\n${GREEN}Você não reinstalou QB64PE e InForm.\n${BLUE}\nTente novamente quando você estará pronto.\n\Adeus.\n${BACK}$dlg000\n"
    dlg020="Você está pronto para desinstalar QB64PE S/n (Enter = Sim)? : "
    dlg021="\n${GREEN}Ok, vamos limpar desinstalar QB64PE.\n"
    dlg022="\n${GREEN}Ok, QB64PE vai ser removido do seu computador e em seguida reinstalado.\n\n${BLUE}No entanto, antes de processar, talvez seja necessário fazer backup de seus\narquivos de origem (.bas).\n\nSe este for o caso, mantenha este script e faça o backup e em seguida, continue."
    dlg022bb="\n${GREEN}Ok, QB64PE vai ser removido do seu computador e em seguida reinstalado.\n\n"
    dlg023="\n${BLUE}Oi ${GREEN}$MYUSERNAME${BLUE} usando os ${RED}privilégios de root${BLUE},"
    dlg024="\n${BLUE}Desculpe, mas como já disse:"
    dlg025="\n${GREEN}QB64PE já estava instalado no seu computador com o script QB64PE_install.sh e não\nfoi desinstalado corretamente do seu computador deixando arquivos indesejados.\n"
    dlg026="${RED}Portanto, não é possível reinstalá-lo imediatamente."
    dlg027="Deseja desinstalar antes da reinstalação S/n (Enter = Sim)? "
    dlg028="${GREEN}\nDesinstale o QB64PE antes de instalá-lo novamente.\n\n${BLUE}Adeus.${BACK}$dlg000\n"
    dlg029="\n${GREEN}Você não instalou o QB64PE.\n${BLUE}\nTente novamente quando estiver pronto.\n\nAdeus.\n${BACK}$dlg000\n"
    dlg030="\n${GREEN}Por favor, seja paciente...\n"
    dlg031="${BLUE}\nEstá tudo pronto."
    dlg032="Você está pronto para instalar o QB64PE & InForm: S/n (Enter = Sim) ? "
    dlg033="${GREEN}OK, haverá apenas uma entrada no menu do aplicativo.${BACK}\n"
    dlg034="${GREEN}Bem, você terá iniciadores de ícones na sua área de trabalho e entradas no menu.${BACK}\n"
    dlg035="Você deseja colocar icon links em seu Desktop: S/n (Enter = Sim)? "
    dlg036="${GREEN}Bem, a pasta $TEMPFOLDER será excluída.${BACK}"
    dlg037="${GREEN}OK, a pasta $TEMPFOLDER não será excluída.${BACK}"
    dlg038="${YELLOW}No final do script, você deseja manter a pasta $TEMPFOLDER para verificar o"
    dlg039="que foi feito durante a instalação: s/N (Enter = Não)? "
    dlg040="${GREEN}\nConstruindo biblioteca LibQB ...\n${BACK}"
    dlg041="${GREEN}Construindo biblioteca FreeType...\n${BACK}"
    dlg042="${GREEN}Construindo Contribuições de Usuários...\n${BACK}"
    dlg043="${GREEN}Construindo biblioteca Core:FreeGLUT...\n${BACK}"
    dlg044="${GREEN}Construindo o QB64PE...\n${BACK}"
    dlg045="${GREEN}\nCompilando o QB64PE...\n${BACK}"
    dlg045b="${RED}QB64PE foi criado.\n${BACK}"
    dlg045c="${GREEN}Agora compilando InForm...\n${BACK}"
    dlg045d="${RED}\nInForm foi criado.\n${BACK}"
    dlg046="${GREEN}Instalação do QB64PE e InForm...\n${BACK}"
    dlg047="${GREEN}\nA instalação está completa.\nAgora você pode finalmente executar o QB64PE de qualquer sessão de terminal sem estar no diretório do QB64PE\ncomo faria com o GCC apenas digitando 'qb64pe' ou executando a linha de comando de compilação\n'qb64pe -x arquivo_de_origem.bas -o arquivo_executável' e possivelmente adicionando a fonte e \no destino diretórios.\nb64 -x /source_directory/source_file.bas -o /destination_directory/executable_file\n"
    dlg048="\n${GREEN}Removendo $TEMPFOLDER.\n${BACK}"
    dlg048b="${RED}You still have the $TEMPFOLDER folder to check what the script did.\n${BACK}"
    dlg049="${RED}\nInfelizmente, parece que o arquivo executável qb64pe não foi criado.\n\n${GREEN}Isso geralmente é uma indicação de uma falha de compilação e você provavelmente\nviu muitas mensagens de erro aparecer na tela.\n\nNormalmente, estas são devido à falta de pacotes necessários para a compilação.\n\nSe você precisar de ajuda, sinta-se à vontade para postar no fórum QB64PE\nou envie um e-mail para: admin@as2.com\n\nPor favor, detalhe o que aconteceu ea distribuição que você está usando\nos comandos da próxima linha:\n\n${BACK}lsb_release -sd && lsb_release -sc && lsb_release -sr && uname -r\n"
    dlg050="${BLUE}Desculpe pela inconveniência.\n\nAdeus.\n${BACK}$dlg000\n"
    dlg051="${BLUE}Obrigado por usar o script QB64PE_install.sh.\n\n${RED}To safely uninstall QB64PE & InForm-pe, just restart the script.\n\n${BLUE}Tudo de bom.\n${BACK}$dlg000\n"
    dlg052="${GREEN}\nVerifique e, se não estiver presente, instale as dependências necessárias para compilar o QB64PE...\n${BACK}"
    dlg053="${GREEN}\nFazendo o download do QB64PE & InForm...${BACK}\n"
    dlg054="${GREEN}Descompactando o QB64PE...${BACK}"
    dlg055="${BLUE}Agora, apenas duas últimas perguntas:"
    dlg056="${BLUE}\n\nO próximo passo é baixar e instalar o QB64PE, bem como todas as dependências\nrelevantes necessárias para compilar o QB64PE em $VENDOR $RELEASE.\n\nEnquanto isso, esteja ciente de que esta instalação pode durar até 15 minutos\ndevido ao tempo para baixar, compilar e instalar o QB64PE.\n\nAssim, a velocidade desta instalação depende tanto da potência da sua máquina\nquanto da sua largura de banda de internet.\n"
    dlg057="${GREEN}Você terminou o script e nada foi feito em seu computador.\n\n${BLUE}Reinicie este script quando você precisar dele.\n\nAdeus.${BACK}$dlg000"
    dlg058="${GREEN}\nOK. Continuação da instalação...${BACK}"
    dlg059="${BLUE}\nOlá ${GREEN}$MYUSERNAME${BLUE} usa os ${RED}privilégios de root${BLUE},\n\nAgora, esse script instala o ${GREEN}$QB64PERE${BLUE} assim como todas\nas dependências necessárias de acordo com suas especificações de distribuição.\n\nSeu sistema operacional é: ${RED}$SYSTEM $VENDOR $RELEASE${BLUE} com as seguintes características:\n\n Nome:   ${RED}$DISTRONAME\n ${BLUE}Sabor:  ${RED}$FLAVOR bits\n ${BLUE}Núcleo: ${RED}$KERNEL\n\n${BLUE}Por padrão:\n\n A pasta de instalação do QB64PE é: ${RED}$QB64PEFOLDER\n${BLUE} A pasta de instalação TEMP é: ${RED}$TEMPFOLDER\n\n"
    dlg060="${RED}Desculpe, mas depois de ${BACK}9${RED} tentar, não foi possível fazer o download de $SOURCE$FILE"
    dlg061="Deseja tentar novamente agora: s/N (Enter = Não) ? : "
    dlg062="${GREEN}Tentando novamente fazer o download de $SOURCE$FILE"
    dlg063="${RED}Este script não pode continuar sem $FILE2\n\n\${GREEN}Verifique a sua conexão à Internet e reinicie o script.\n\nSe o problema persistir, instale $FILE manualmente e relate-o para admin@as2.com\n\n${BLUE}Adeus.${BACK}$dlg000"
    dlg064="${RED}\nDesculpe, mas depois de ${BACK}5${RED} tentar, não consigo instalar $PACKET"
    dlg065="Deseja tentar novamente agora: s/N (Enter = Não)? : "
    dlg066="${GREEN}Tentando novamente instalar $PACKET"
    dlg067="${RED}Desculpe, mas este script não pode continuar sem $PACKET\n\n${GREEN}Verifique a sua conexão à Internet e reinicie o script.\n${BLUE}Adeus${BACK}$dlg000"
    dlg068="\n${BLUE}Olá $ME,${RED}\n\nVocê deve instalar o lsb_release para usar este script."
    dlg069="Deseja instalar lsb_release agora: S/n (Enter = Sim) ? "
    dlg070="\n${RED}Este script não pode continuar sem lsb_release.\n\n${GREEN}Instale o lsb_release e reinicie o script.\n\n${BLUE}Adeus.${BACK}$dlg000"
    dlg071="${RED}Por favor, você deve instalar o wget para usar este script."
    dlg072="Deseja instalar o wget agora: S/n (Enter = Sim) ? "
    dlg073="${GREEN}Este script não pode continuar sem o wget.\nInstale o wget e reinicie o script.\n\n${BLUE}Adeus.${BACK}$dlg000"
    dlg074="\n${BLUE}Olá $ME,\n\n${RED}Você deve usar os privilégios de root para usar este script.\n\n${GREEN}Reinicie este script usando ${BACK}[sudo]${GREEN} ou ${BACK}[su]${GREEN} ou ${BACK}[su -]${GREEN} de acordo com a política\nde segurança do seu sistema operacional.\n\n${BLUE}Adeus.${BACK}\n\n--------------------------------------------------------------------------------\n"
    dlg075="${BLUE}\nThe script can backup your $QB64PEFOLDER into your /home/$MYUSERNAME/backup-qb64pe.${YELLOW}\n"
    dlg076="Do you want to backup your $QB64PEFOLDER Y/n (empty return = Yes )? "
    dlg077="${RED}\nOK, your $QB64PEFOLDER is not saved into /home/$MYUSERNAME/backup-qb64pe.${GREEN}\n\nPlease check what to do with your $QB64PEFOLDER folder (move or rename or delete\nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg078="${GREEN}\nOK, the script is saving your $QB64PEFOLDER into /home/$MYUSERNAME/backup-qb64pe"
    dlg079="${RED}\nWARNING! the directory /home/$MYUSERNAME/backup-qb64pe already exists!\n"
    dlg080="So, your current /opt/qb64pe foldder wasn't saved, yet.\n\n${BLUE}Please check what to do with your previous /home/$MYUSERNAME/backup-qb64pe folder\n(move or rename or delete\nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
    dlg081="\n${GREEN}Now, QB64PE was saved into /home/$MYUSERNAME/backup-qb64pe\n"
    dlg082="Are you ready to remove the previous $QB64PEFOLDER now: Y/n (empty return = Yes) ? "
    dlg083="\n${GREEN}You didn't reinstall QB64PE and InForm.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
    dlg099="${RED}Thanks for their times and tremandous advice helping me to make this script to:\n\nFrom the https://forum.ubuntu-fr.org community (by alphabetical order):\nAmiralgaby, Bousky, Clémentv, grim7reaper, epehj, hoper, Hizoka, MicP, nesthib,\npingouinux, The Uploader, tiramiseb, Watael and many others.\n\nFrom the https://forums.fedora-fr.org community (by alphabetical order): fgland,\nmadko, nouvo09, pingou, remi and many others.\n\nFrom the http://www.manjaro.fr community (by alphabetical order): ewolnux,\nlemust83, loubrix, papajoke, patri-arch, smurf, waitnsea and many others.\n\nFrom the https://www.centos.org community (by alphabetical order): bob, Emma,\nMartinR, stevemowbray, TrevorH and many others.\n\nFrom the https://ubuntuforums.org community (by alphabetical order): steeldriver\nand many others.\n\nFrom the https://qb64phoenix.com/forum/index.php community: Donald, doppler,\nFlukiluke and many others.\n\nSpecial thanks to Fellippe Heitor for his open source project InForm."
}
# --------------------------------------------------------------------------------
#
# Pause
#
pause()
{
    RESPONSE=""
    #dlg001="Please, hit the [Enter] key to continue..."
    $ECHO "${YELLOW}"
    read -p "$dlg001" RESPONSE
    clear
    $ECHO "${BACK}"
}
#
# --------------------------------------------------------------------------------
#
display_credits()
{
    #dlg099="${RED}Thanks for their times and tremandous advice helping me to make this script to:\n\nFrom the https://forum.ubuntu-fr.org community (by alphabetical order):\nAmiralgaby, Bousky, Clémentv, grim7reaper, epehj, hoper, Hizoka, MicP, nesthib,\npingouinux, The Uploader, tiramiseb, Watael and many others.\n\nFrom the https://forums.fedora-fr.org community (by alphabetical order): fgland,\nmadko, nouvo09, pingou, remi and many others.\n\nFrom the http://www.manjaro.fr community (by alphabetical order): ewolnux,\nlemust83, loubrix, papajoke, patri-arch, smurf, waitnsea and many others.\n\nFrom the https://www.centos.org community (by alphabetical order): bob, Emma,\nMartinR, stevemowbray, TrevorH and many others.\n\nFrom the https://ubuntuforums.org community (by alphabetical order): steeldriver\nand many others.\n\nFrom the https://qb64phoenix.com/forum/index.php community: Donald, doppler\nFlukiluke and many others.\n\nSpecial thanks to Fellippe Heitor"
    $ECHO "$dlg099"
    pause
}
#
#-------------------------------------------------------------------------------
#
# show the information about the use of this script
#
show_info()
{
    $ECHO "$dlg002"
    pause
}
#-------------------------------------------------------------------------------

#
# set the account user name using root priviledges
#
set_user_name()
{
#
# I know, it's already done but don't ask me why and please don't remove the next line.
#
    get_tongue
    case $VALID_USER in
        0)
            #dlg003="\n${GREEN}OK, the account user name${RED} $MYUSERNAME ${GREEN}is valid on this system.\n"
            $ECHO "$dlg003"; pause;;
        *)
            #dlg004="\n${GREEN}Sorry, the account user name${RED} $MYUSERNAME ${GREEN}can't be used on this system.\n\n${BLUE}Please retry."
        $ECHO "$dlg004"; MYUSERNAME=""; pause;;
    esac
}
#-------------------------------------------------------------------------------
#
# check if the account user name is valid
#
check_user_name()
{
    if [ "$REFUSED_NAME" != 0 ]
        then
            if id -u "$MYUSERNAME"> /dev/null 2>&1
                then
                    VALID_USER=0
                else
                    VALID_USER=1
            fi
    fi
}
#-------------------------------------------------------------------------------
#
# control if the account user name isn't a restricted name
#
check_refused_names()
{
    case $MYUSERNAME in
        '_apt'|'abrt'|'adm'|'apache'|'avahi'|'avahi-autoipd'|'backup'|'bin'|'chrony'|'colord'|'deamon'|'dbus'|'dnsmasq'|'ftp'|'games'|'gdm'|'geoclue'|'gnat'|'gnome-initial-setup'|'halt'|'hplip'|'http'|'irc'|'kernoops'|'lightdm'|'list'|'lp'|'mail'|'man'|'messagebus'|'nbd'|'news'|'nfsnobody'|'nm-openconnect'|'nobody'|'ntp'|'openvpn'|'operator'|'polkitd'|'proxy'|'pulse'|'qmenu'|'radvd'|'rm-openvpn'|'root'|'rpc'|'rpcuser'|'rtkit'|'saned'|'saslauth'|'setroubleshoot'|'shutdown'|'speech-dispatcher'|'sshd'|'sync'|'sys'|'syslog'|'systemd-bus-proxy'|'systemd-coredump'|'systemd-journal-gateway'|'systemd-journal-remote'|'systemd-journal-upload'|'systemd-network'|'systemd-resolve'|'systemd-timesync'|'tcpdump'|'tss'|'unbound'|'usbmux'|'usbmuxd'|'uupc'|'uuidd'|'whoopsie'|'www-data')
            REFUSED_NAME=0;;
        *)
            REFUSED_NAME=1;;
    esac
}
#-------------------------------------------------------------------------------
#
# ask to enter the account user name which will use root priviledges
#
ask_user_name()
{
    #dlg005="Please enter your account user name to continue: ? "
    read -p "$dlg005" MYUSERNAME
    if [ "$MYUSERNAME" = "" ]
        then
            #dlg006="\n${GREEN}Your account user name is empty.\n"
            $ECHO "$dlg006"
            $ECHO -n ${YELLOW}
            #dlg007="Do you want to enter your user name to continue: Y/n (empty return = Yes)? "
            read -p "$dlg007" RESPONSE_RETRY
            if [ "$RESPONSE_RETRY" = "" ] || [ "$RESPONSE_RETRY" = "Y" ] || [ "$RESPONSE_RETRY" = "y" ]
                then
                    clear
                        $ECHO "\n"
                    ask_user_name
                else
                    #dlg008="\n${RED}Sorry, this script can't continue without knowing your user name.${BLUE}\n\nGoodbye.${BACK}$dlg000"
                    $ECHO "$dlg008"
                    exit 0
            fi
    fi
}
# --------------------------------------------------------------------------------
#
# Check the use of sudo, su or su - to allow executing the complete script.
#
check_priviledges()
{
    #dlg009="\n${BLUE}Hello,"
    $ECHO "$dlg009"
    if [ "$ME" != "root" ]
        then
            #dlg010="\n${RED}WARNING\n-------\n"
            $ECHO "$dlg010"
        case $VENDOR in
            'Debian'|'Raspbian'|'elementary'|'LMDE'|'Mint'|'Ubuntu'|'Zorin'|'Neon')
                #dlg011="${RED}This script can't be used without the root privileges (i.e.${BACK} [sudo]${RED} or ${BACK}[su]${RED} or ${BACK}[su -]${RED}).\n\n${GREEN}Please restart the script with the command: ${BACK}[sudo ./QB64PE_install.sh]${GREEN} or start\na ${RED}root session${GREEN} \nusing ${BACK}[su]${GREEN} or ${BACK}[su -]${GREEN}, then start ${BACK}[./QB64PE_install.sh]\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
                $ECHO "$dlg011";;
            *)
                #dlg012="${RED}This script can't be used without the root privileges (${BACK}[su -]${RED}).\n\n${GREEN}Please start a ${RED}root session${GREEN} using ${BACK}[su -]${GREEN} and not ${RED}([su])${GREEN} then goto\nthe folder where you've installed this script and start ${BACK}[./test_sudo.sh]\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
                $ECHO "$dlg012";;
        esac
        exit 0
    fi
    while [ "$MYUSERNAME" = "" ]
        do
            #dlg013="\n${RED}WARNING\n-------\n\n${GREEN}You're using the ${RED}root${GREEN} account priviledges.\n\nSo, I can't guess ${RED}your real account user name${GREEN} and this script needs this\ninformation to continue.\n"
            $ECHO "$dlg013"
            $ECHO -n ${YELLOW}
            ask_user_name
            check_refused_names
            check_user_name
            set_user_name
        done
}
# --------------------------------------------------------------------------------
#
# check if the dependencies needed for QB64PE are already installed
#
check_dependencies()
{
    TOINSTALL=""
    for DEPENDENCIE in $INSTALL_LIST
        do
            if [ -z "$(echo "$PRESENCE" | grep $DEPENDENCIE)" ]
                then
                TOINSTALL=$DEPENDENCIE
                fi
        done
}
# --------------------------------------------------------------------------------
#
# delete the QB64PE folder
#
clean_qb64pe_1()
{
    QB64PE_1=$(find /opt -type d -name "qb64pe" | wc -l)
    if [ "$QB64PE_1" != 0 ]
        then
            #dlg014="${BACK}\nDeleting the previous QB64PE folder.\n${BACK}"
            $ECHO "$dlg014"
            rm -R $QB64PEFOLDER
    fi
}
# --------------------------------------------------------------------------------
#
# delete the temp install folder
#
clean_qb64pe_2()
{
    QB64PE_2=$(find /opt -type d -name "qb64pe-tmp" | wc -l)
    if [ "$QB64PE_2" != 0 ]
        then
            #dlg015="${BACK}\nDeleting the previous temporary install folder.\n${BACK}"
            $ECHO "$dlg015"
            rm -R $TEMPFOLDER
    fi
}
# --------------------------------------------------------------------------------
#
# delete the desktop QB64PE, InForm starters
#
clean_qb64pe_3()
{
    case $TONGUE in
        'en'|'de'|'es'|'fr'|'it'|'be'|'pt')
            QB64PE_3=$(find "/home/$MYUSERNAME/$DESKTOP_NAME" -type f -name "QB64PE IDE.desktop" | wc -l);;
        *)
            QB64PE_3=0;;
    esac
    if [ "$QB64PE_3" = 0 ]
        then
        case $TONGUE in
            'en'|'de'|'es'|'fr'|'it'|'be'|'pt')f
                #dlg016="${BACK}\nDeleting the QB64PE desktop starter.\n${BACK}"
                $ECHO "$dlg016"; rm -Rf "/home/$MYUSERNAME/$DESKTOP_NAME/QB64PE IDE.desktop";;
            *)
        esac
    fi
    case $TONGUE in
        'en'|'de'|'es'|'fr'|'it'|'be'|'pt')
            QB64PE_3=$(find "/home/$MYUSERNAME/$DESKTOP_NAME" -type f -name "InForm for QB64PE.desktop" | wc -l);;
        *)
        QB64PE_3=0;;
    esac
    if [ "$QB64PE_3" != 0 ]
        then
            case $TONGUE in
                'en'|'de'|'es'|'fr'|'it'|'be'|'pt')
                    #dlg016b="${BACK}\nDeleting the InForm desktop starter.\n${BACK}"
                    $ECHO "$dlg016b"; rm -R "/home/$MYUSERNAME/$DESKTOP_NAME/InForm for QB64PE.desktop";;
                *)
            esac
    fi
    case $TONGUE in
        'en'|'de'|'es'|'fr'|'it'|'be'|'pt')
            QB64PE_3=$(find "/home/$MYUSERNAME/$DESKTOP_NAME" -type l -name "qb64pe" | wc -l);;
        *)
            QB64PE_3=0;;
    esac
    if [ "$QB64PE_3" != 0 ]
        then
            case $TONGUE in
                'en'|'de'|'es'|'fr'|'it'|'be'|'pt')
                    #dlg016d="${BACK}\nDeleting the qb64pe folder desktop link.\n${BACK}"
                    $ECHO "$dlg016d"; rm -R "/home/$MYUSERNAME/$DESKTOP_NAME/qb64pe";;
            *)
        esac
    fi
}
# --------------------------------------------------------------------------------
#
# delete the qb64pe.sh and qb64pe.csh
#
clean_qb64pe_4()
{
    QB64PE_4=$(find /etc/profile.d -type f -name "qb64pe*" | wc -l)
    if [ "$QB64PE_4" != 0 ]
        then
            #dlg017="${BACK}\nDeleting the QB64PE path and/or bash starter.\n${BACK}"
            $ECHO "$dlg017"
            rm -R /etc/profile.d/qb64pe*
    fi
    QB64PE_4b=$(find /usr/bin -type f -name "qb64pe*" | wc -l)
    if [ "$QB64PE_4b" != 0 ]
        then
            #dlg017="${BACK}\nDeleting the QB64PE path and/or bash starter.\n${BACK}"
            $ECHO "$dlg017"
            rm -R /usr/bin/qb64pe*
    fi
    QB64PE_4c=$(find /etc/profile.d -type f -name "inform*" | wc -l)
    if [ "$QB64PE_4c" != 0 ]
        then
            #dlg017="${BACK}\nDeleting the QB64PE path and/or bash starter.\n${BACK}"
            $ECHO "$dlg017"
            rm -R /etc/profile.d/inform*
    fi
    QB64PE_4d=$(find /usr/bin -type f -name "inform*" | wc -l)
    if [ "$QB64PE_4d" != 0 ]
        then
            #dlg017="${BACK}\nDeleting the QB64PE path and/or bash starter.\n${BACK}"
            $ECHO "$dlg017"
            rm -R /usr/bin/inform*
    fi
}
# --------------------------------------------------------------------------------
#
# delete the QB64PE menu entry
#
clean_qb64pe_5()
{
    QB64PE_5=$(find /usr/share/applications -type f -name "QB64PE IDE.desktop" | wc -l)
    if [ "$QB64PE_5" != 0 ]
        then
            #dlg018="${BACK}\nDeleting the QB64PE IDE menu entry.\n${BACK}"
            $ECHO "$dlg018"
            rm -R /usr/share/applications/"QB64PE IDE.desktop"
    fi
    QB64PE_6=$(find /usr/share/applications -type f -name "InForm for QB64PE.desktop" | wc -l)
    if [ "$QB64PE_6" != 0 ]
        then
            #dlg018b="${BACK}\nDeleting the InForm menu entry.\n${BACK}"
            $ECHO "$dlg018b"
            rm -R /usr/share/applications/"InForm for QB64PE.desktop"
    fi
}
# --------------------------------------------------------------------------------
#
# cleanly uninstall QB64PE
#
uninstall_qb64pe()
{
    if [ "$REMOVEQB64PE" = "Y" ]  || [ "$REMOVEQB64PE" = "y" ]
        then
            clean_qb64pe_1
            clean_qb64pe_2
            clean_qb64pe_3
            clean_qb64pe_4
            clean_qb64pe_5
            #dlg019="\n${GREEN}QB64PE & InForm were cleanly removed from your computer.\n\n"
            $ECHO "$dlg019"
            $ECHO "${YELLOW}"
            #dlg019b="Do you want to reinstall QB64PE & InForm Y/n (empty return = Yes)? : "
            read -p "$dlg019b" REINSTQB64PE
            case $REINSTQB64PE in
                'N'|'n')
                #dlg019c="\n${GREEN}You didn't reinstall QB64PE & InForm.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
                $ECHO "$dlg019c"; exit 0;;
            *)
            esac
    fi
}

# --------------------------------------------------------------------------------
#
# backup QB64PE into /home/qb64pe-backup
#
backup_qb64pe()
{
    BACKUPFOLDER=$(find /home/$MYUSERNAME -type d -name "backup-qb64pe" | wc -l)
    if [ "$BACKUPFOLDER" != 0 ]
        then
            #dlg079="${RED}\nWARNING! the directory /home/$MYUSERNAME/backup-qb64pe already exists!\n"
            $ECHO "$dlg079"
            #dlg080="So, your current /opt/qb64pe foldder wasn't saved, yet.\n\n${BLUE}Please check what to do with your previous /home/$MYUSERNAME/backup-qb64pe folder\n(move or rename or delete it) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
            $ECHO "$dlg080"
            exit 0
        else
            sleep 5
            mkdir "/home/$MYUSERNAME/backup-qb64pe"
            cp -R "$QB64PEFOLDER" "/home/$MYUSERNAME/backup-qb64pe"
            chown -R -f $MYUSERNAME "/home/$MYUSERNAME/backup-qb64pe"
            chmod -fR 777 "/home/$MYUSERNAME/backup-qb64pe"
            #dlg081="\n${GREEN}Now, QB64PE is saved into /home/$MYUSERNAME/backup-qb64pe\n"
            $ECHO "$dlg081"
            sleep 2
            BACKUPDONE=1
            #dlg082="Are you ready to remove the previous $QB64PEFOLDER now: Y/n (empty return = Yes) ? "
            $ECHO ${YELLOW}
            read -p "$dlg082" CONTINUEINSTALL
            case $CONTINUEINSTALL in
                'N'|'n')
                    #dlg083="\n${GREEN}You didn't reinstall QB64PE and InForm.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
                    REMOVEQB64PE="N"; $ECHO $dlg083; exit 0;;
                *)
            esac
    fi
    REMOVEQB64PE="Y"
    uninstall_qb64pe
}
# --------------------------------------------------------------------------------
#
# response to uninstall QB64PE
#
get_response_uninstall()
{
    $ECHO "${YELLOW}\n"
    #dlg020="Are you ready to uninstall QB64PE Y/n (empty return = Yes)? : "
    read -p "$dlg020" REMOVEQB64PE
    case $REMOVEQB64PE in
        'N'|'n')
            TWICE=1; do_uninstall;;
        *)
            #dlg021="\n${GREEN}Ok, we're going to cleanly uninstall QB64PE.\n"
            $ECHO "$dlg021"; REMOVEQB64PE="Y"; uninstall_qb64pe;;
    esac
}
# --------------------------------------------------------------------------------
#
# ask to uninstall QB64PE
#
ask_uninstall()
{
    clear
#    QB64PE_0="$(find /opt -type d -name "qb64pe" | wc -l)"
#    $ECHO "/opt/qb64pe présent -$QB64PE_0-"
#    pause
    #dlg022="\n${GREEN}Ok, QB64PE is going to be cleanly removed from your computer then reinstalled.\n"
    $ECHO $dlg022b
    QB64PE_0="$(find /opt -type d -name "qb64pe" | wc -l)"
#    $ECHO "/opt/qb64pe présent -$QB64PE_0-"
#    pause
    if [ "$QB64PE_0" != "0" ]
        then
            #dlg075"${BLUE}\nThe script can backup your $QB64PEFOLDER into your /home/$MYUSERNAME/backup-qb64pe.${YELLOW}\n"
            $ECHO $dlg075
            #dlg076="Do you want to backup your $QB64PEFOLDER Y/n (empty return = Yes )? "
            read -p "$dlg076" DOBACKUP
            case $DOBACKUP in
                'N'|'n')
                    #dlg077="${RED}\nOK, your $QB64PEFOLDER is not saved into /home/$MYUSERNAME/backup-qb64pe.${GREEN}\n\nPlease check what to do with your $QB64PEFOLDER folder (move or rename or delete\nit) and restart the script when you'll be ready.\n\n${BLUE}Goodbye.\n${BACK}$dlg000\n"
                    $ECHO $dlg077; exit 0;;
                *)
                    #dlg078="${GREEN}\nOK, the script will save your $QB64PEFOLDER into your /home/$MYUSERNAME/backup-qb64pe."
                    $ECHO $dlg078; backup_qb64pe;;
            esac
        else
    #dlg022="\n${GREEN}Now, QB64PE is going to be cleanly removed from your computer then reinstalled.\n
#    $ECHO "$dlg022"
    get_response_uninstall
  fi
}
# --------------------------------------------------------------------------------
#
# propose to do or cancel the uninstall of QB64PE
#
do_uninstall()
{
    clear
    $ECHO "$dlg023"
    if [ "$TWICE" = 1 ]
        then
        clear
        #dlg024="\n${BLUE}Sorry, but as already said:"
        $ECHO "$dlg024"
    fi
    #dlg025="\n${GREEN}QB64PE was already installed on your computer with the QB64PE_install.sh script\nand was not cleanly uninstalled from your computer leaving unwanted files.\n"
    $ECHO "$dlg025"
    #dlg026="${RED}So, it's not possible to reinstall it right away."
    $ECHO "$dlg026"
    $ECHO "${YELLOW}"
    #dlg027="Do you want to cleanly uninstall prior reinstalling Y/n (empty return = Yes)? "
    read -p "$dlg027" UNINSTALL
    if [ "$UNINSTALL" = "N" ] || [ "$UNINSTALL" = "n" ]
        then
            #dlg028="${GREEN}\nPlease uninstall QB64PE before to install it again.\n\n${BLUE}Goodbye.${BACK}$dlg000\n"
            $ECHO "$dlg028"
            exit 0
        else
            ask_uninstall
    fi
}
# --------------------------------------------------------------------------------
#
# check if QB64PE is installed with this script
#
check_qb64pe()
{
    QB64PE_1=$(find /opt -type d -name "qb64pe" | wc -l)
    QB64PE_2=$(find /opt -type d -name "qb64pe-tmp" | wc -l)
    case $TONGUE in
        'en'|'de'|'es'|'fr'|'it'|'be'|'pt')
            QB64PE_3=$(find "/home/$MYUSERNAME/$DESKTOP_NAME" -type f -name "QB64PE IDE.desktop" | wc -l);;
        *)
        QB64PE_3=0;;
    esac
    QB64PE_4=$(find /etc/profile.d -type f -name "QB64PE*" | wc -l)
    QB64PE_4b=$(find /etc/profile.d -type f -name "InForm*" | wc -l)
    QB64PE_5=$(find /usr/share/applications -type f -name "QB64PE IDE.desktop" | wc -l)
    QB64PE_6=$(find /usr/share/applications -type f -name "InForm for QB64PE.desktop" | wc -l)
    if [ "$QB64PE_1" != 0 ] || [ "$QB64PE_2" != 0 ] || [ "$QB64PE_4" != 0 ] || [ "$QB64PE_4b" != 0 ] || [ "$QB64PE_5" != 0 ] || [ "$QB64PE_6" != 0 ]]
        then
            do_uninstall
    fi
}
#--------------------------------------------------------------------------------
#
# Now, get the response to start the install
#
get_response_start()
{
    case $GOFORQB64PEINSTALL in
        'N'|'n')
            #dlg029="\n${GREEN}You didn't install QB64PE.\n${BLUE}\nPlease retry when you'll be ready.\n\nGoodbye.\n${BACK}$dlg000\n"
            $ECHO "$dlg029"; exit 0;;
        *)
            #dlg030="\n${GREEN}The QB64PE installation starts. Please be patient...\n"
            $ECHO "$dlg030";;
    esac
}
# --------------------------------------------------------------------------------
#
#  ask to install QB64PE and all its dependencies
#
request_start()
{
    #dlg031="${BLUE}\nYou're all set."
    $ECHO "$dlg031"
    $ECHO "${YELLOW}"
    #dlg032="Are you ready to install QB64PE & InForm: Y/n (empty return = Yes) ? "
    read -p "$dlg032" GOFORQB64PEINSTALL
    get_response_start
}
# --------------------------------------------------------------------------------
#
# get the response to place a QB64PE & InForm starter on the desktop
#
get_response_starter()
{
    case $PUTSTARTER in
        'N'|'n')
            #dlg033="${GREEN}OK, there will be only entries in the application menu.${BACK}\n"
            $ECHO "$dlg033";;
        *)
            #dlg034="${GREEN}Well, you'll have icon starters on your desktop and entries in the menu.${BACK}\n"
            $ECHO "$dlg034";;
    esac
}
# --------------------------------------------------------------------------------
#
# ask for placing a QB64PE & Inform icon starters on the desktop
#
request_starter()
{
    $ECHO "${YELLOW}"
    #dlg035="Do you want to put icon links on your desktop: Y/n (empty return = Yes)? "
    read -p "$dlg035" PUTSTARTER
    if [ "$PUTSTARTER" = "" ]
        then
            PUTSTARTER="Y"
    fi
    $ECHO "${BACK}"
    get_response_starter
}
# --------------------------------------------------------------------------------
#
# delete the temp folder
#
delete_temp_folder()
{
    case $KEEPTEMP in
        'N'|'n')
            rm -R $TEMPFOLDER;;
        *)
    esac
}
# --------------------------------------------------------------------------------
#
# get the response to keep the temp folder
#
get_response_keep()
{
    case $KEEPTEMP in
        'N'|'n')
            #dlg036="${GREEN}Well, the $TEMPFOLDER folder will be deleted.${BACK}"
            $ECHO "$dlg036";;
        *)
            #dlg037="${GREEN}OK, the $TEMPFOLDER folder will not be deleted.${BACK}"
            $ECHO "$dlg037";;
    esac
    pause
}
# --------------------------------------------------------------------------------
#
# ask for keeping the temp folder
#
request_keep()
{
    #dlg038="${YELLOW}At the end of the script, do you want to keep the $TEMPFOLDER folder to"
    $ECHO "$dlg038"
    #dlg039="check what was done during the installation: N/y (empty return = No)? "
    read -p "$dlg039" KEEPTEMP
    if [ "$KEEPTEMP" = "" ]
        then
            KEEPTEMP="N"
    fi
    $ECHO "${BACK}"
    get_response_keep
}
# --------------------------------------------------------------------------------
#
# install the products
#
install_products()
{
    #dlg046="${GREEN}Installing QB64PE & InForm...\n${BACK}"
    $ECHO "$dlg046"
    mkdir "$QB64PEFOLDER"
    cp -Rf $TEMPFOLDER/qb64pe/* $QB64PEFOLDER
    chmod -fR 777 $QB64PEFOLDER
    rm -R $QB64PEFOLDER/internal/temp/*
    #
    # add the QB64PE IDE & InForm GDE menu entries
    #
    if [ $QB64PEDONE = "1" ]
        then
            cp "$TEMPFOLDER/qb64pe/Starters-pe/QB64PE IDE.desktop" /usr/share/applications
            chmod +x "/usr/share/applications/QB64PE IDE.desktop"
    fi
    if [ $INFORMDONE = "1" ] && [ $INFORMDONE2 = "1" ]
        then
            cp "$TEMPFOLDER/qb64pe/Starters-pe/InForm for QB64PE.desktop" /usr/share/applications
            chmod +x "/usr/share/applications/InForm for QB64PE.desktop"
    fi
    #
    # add the qb64pe.sh & inform bash scripts in /usr/bin & /etc/profile to start QB64PE from anywhere ...
    #
    cp $TEMPFOLDER/qb64pe/Starters-pe/qb64pe.sh /usr/bin/qb64pe
    chmod +x /usr/bin/qb64pe
    cp $TEMPFOLDER/qb64pe/Starters-pe/qb64pe.sh /etc/profile.d/qb64pe
    chmod +x /etc/profile.d/qb64pe
    cp $TEMPFOLDER/qb64pe/Starters-pe/inform.sh /usr/bin/inform-pe
    chmod +x /usr/bin/inform-pe
    cp $TEMPFOLDER/qb64pe/Starters-pe/inform.sh /etc/profile.d/inform-pe
    chmod +x /etc/profile.d/inform-pe
    #
    # if requested, add a QB64PE IDE & the InForm GDE starters and the qb64pe folder on the user desktop
    #
    if [ "$PUTSTARTER" != "N" ] || [ "$PUTSTARTER" != "n" ]
        then
            ln -s "$QB64PEFOLDER" -t "/home/$MYUSERNAME/$DESKTOP_NAME"; cp "/usr/share/applications/QB64PE IDE.desktop" "/usr/share/applications/InForm for QB64PE.desktop" "/home/$MYUSERNAME/$DESKTOP_NAME"; chmod +x "/home/$MYUSERNAME/$DESKTOP_NAME/QB64PE IDE.desktop" "/home/$MYUSERNAME/$DESKTOP_NAME/InForm for QB64PE.desktop"; chown $MYUSERNAME "/home/$MYUSERNAME/$DESKTOP_NAME/QB64PE IDE.desktop" "/home/$MYUSERNAME/$DESKTOP_NAME/InForm for QB64PE.desktop";
      #
      # else remove the starters and the link to the folder /opt/qb64pe
      #
         else
             #
             # Check if QB64PE is created then remove its starter
             #
             if [ $QB64PEDONE != "1" ]
                 then
                     rm "/home/$MYUSERNAME/$DESKTOP_NAME/QB64PE IDE.desktop"
             fi
             #
             # Check if Inform is created then remove its starter
             #
             if [ $INFORMDONE != "1" ]
                 then
                     rm "/home/$MYUSERNAME/$DESKTOP_NAME/InForm for QB64PE.desktop"
             fi
             rm -R "/home/$MYUSERNAME/$DESKTOP_NAME/QB64PE IDE"
         fi
         #
         # if requested, delete the $TEMPFOLDER folder
         #
         if [ $KEEPTEMP = "N" ] || [ $KEEPTEMP = "n" ]
             then
                 #dlg048="${GREEN}Removing $TEMPFOLDER.\n${BACK}"
                 $ECHO "$dlg048"
                 rm -R "$TEMPFOLDER"
             else
                 #dlg048b="${RED}You still have the $TEMPFOLDER folder to check what was going wrong.\n${BACK}"
                 $ECHO "$dlg048b"
                 chown -f -R $MYUSERNAME $TEMPFOLDER
                 chmod -R 777 "$TEMPFOLDER"
         fi
         chown -R -f $MYUSERNAME $QB64PEFOLDER
         #dlg047="${GREEN}\nThe installation is complete.\n\n${GREEN}Now, you can finally run QB64PE from any terminal session ${RED}without being into the\nQB64PE's directory${GREEN} (as you would with GCC) just by typing ${RED}'qb64pe' ${GREEN}or running\nthe compile command line: ${RED}'qb64pe -x source_file.bas -o executable_file'\n${GREEN}and even adding the source and destination directories:\n${RED}'qb64pe -x /source_dir/source_file.bas -o /destination_dir/executable_file'\n"
         $ECHO "$dlg047"
         pause
}
# --------------------------------------------------------------------------------
#
# compile the QB64PE & InForm packages
#
compile_qb64pe()
{
    cd $TEMPFOLDER/qb64pe
    #dlg045="\n${RED}Compiling QB64PE...\n${BACK}"
    $ECHO "$dlg045"
    sleep 3
    make clean OS=lnx
    make OS=lnx BUILD_QB64=y -j3
    QB64PEDONE=$(find $TEMPFOLDER/qb64pe -type f -iname "qb64pe" | wc -l)
    if [ $QB64PEDONE = "1" ]
        then
            #dlg045b="\n${RED}QB64PE was created.\n${BACK}"
            $ECHO "$dlg045b"
            #
            # compile InForm with QB64PE
            #
            #dlg045c="${GREEN}Now compiling InForm with the new QB64PE compiler...\n${BACK}"
            $ECHO "$dlg045c"
            mv ../falcon.h falcon.h
            sleep 3
            ./qb64pe -x -q InForm/updater/InFormUpdater.bas -o InForm/updater/InFormUpdater
            $ECHO "\n\n"
            sleep 3
            ./qb64pe -x -q InForm/UiEditorPreview.bas -o InForm/UiEditorPreview
            $ECHO "\n\n"
            sleep 3
            ./qb64pe -x -q InForm/UiEditor.bas -o InForm-pe
            INFORMDONE=$(find $TEMPFOLDER/qb64pe -type f -iname "InForm-pe" | wc -l)
#            $ECHO "\n\n"
            sleep 2
            INFORMDONE2=$(find $TEMPFOLDER/qb64pe/InForm/UiEditorPreview -type f -iname "UiEditorPreview" | wc -l)
            if [ $INFORMDONE = "1" ] && [ $INFORMDONE2 = "1" ]
                then
                    sleep 2
                    #dlg045d="\n${GREEN}InForm was created.\n${BACK}"
                    $ECHO $dlg045d
            fi
            #
            # install the products
            #
            install_products
            #
        #
        # QB64PE did not compile
        #
        else
            #dlg049="${RED}\nUnfortunately, it appears that the qb64pe executable file was not created.\n\n${GREEN}This is usually an indication of a compile failure and you probably saw\nlots of error messages pop up on the screen.\n\nUsually these are due to missing packages needed for compilation.\n\nIf you need help, please feel free to post on the QB64PE forum\nor e-mail me at: admin@as2.com\n\nPlease detail what happened and the distribution you're using the three\ncommands of the next line:\n\n${BACK}lsb_release -sd && lsb_release -sc && lsb_release -sr\n"
            $ECHO "$dlg049"
            pause
            echo" check QB64PE"
            QB64PEDONE2=$(find $TEMPFOLDER/qb64pe -type d -iname "qb64pe" | wc -l)
            if [ $QB64PEDONE2 != "1" ]
                then
                    rm -R $QB64PEFOLDER
            fi
            if [ $KEEPTEMP = "N" ] || [ $KEEPTEMP = "n" ]
                then
                    #dlg048="${GREEN}Removing $TEMPFOLDER.\n${BACK}"
                    $ECHO "$dlg048"
                    rm -R "$TEMPFOLDER"
                else
                    #dlg048b="${RED}You still have the $TEMPFOLDER folder to check what the script did.\n${BACK}"
                    $ECHO "$dlg048b"
                    chown -f -R $MYUSERNAME $TEMPFOLDER
                    chmod -R 777 "$TEMPFOLDER"
                fi
            #dlg050="${BLUE}Sorry for the inconvenience.\n\nGoodbye.\n${BACK}$dlg000\n"
            $ECHO "$dlg050"
            exit 0
    fi
    #dlg051="${BLUE}\nThank you for using the QB64PE_install.sh script.\n\n${RED}To safely uninstall QB64PE & InForm-pe, just restart the script.\n\n${BLUE}All the best.\n${BACK}$dlg000\n"
    display_credits
    $ECHO "$dlg051"
    qb64pe &
    $ECHO "\n\n"
    exit 0
}
#
# download and install the other needed packages
#
get_packages()
{
    if [ "$TOINSTALL" = ""  ]
        then
            #dlg052="${GREEN}\nCheck and if not present install the dependencies needed to compile QB64PE...\n${BACK}"
            $ECHO "$dlg052"
            $DISTRO_INSTALL$PACKAGES
    fi
}
# --------------------------------------------------------------------------------
#
# download and install QB64PE
#
get_qb64pe()
{
    #dlg053="${GREEN}\nDownloading QB64PE & InForm...${BACK}\n"
    $ECHO "$dlg053"
    # Download QB64PE
    DESTINSTALL=$TEMPFOLDER
    FILE="qb64pe-$QB64PEREV2.tar.bz2"
    FILE2=$FILE
    SOURCE="http://$SERVER/qb64pe/packages/"
    get_file
    # Download InForm
    FILE="InForm.tar.bz2"
    FILE2=$FILE
    SOURCE="http://$SERVER/qb64pe/packages/"
    get_file
    # Download starters
    # Check to remove the vwatch starter from qb64pe-cmd.tar
    FILE="qb64pe-cmd.tar.bz2"
    FILE2=$FILE
    SOURCE="http://$SERVER/qb64pe/packages/"
    get_file
    #dlg054="${GREEN}Unpacking QB64PE & InForm...${BACK}"
    $ECHO "$dlg054"
    cd $TEMPFOLDER
    tar -xjf qb64pe-$QB64PEREV2.tar.bz2
    tar -xjf InForm.tar.bz2
    cp -Rf InForm qb64pe
    rm -R InForm
    tar -xjf qb64pe-cmd.tar.bz2
    compile_qb64pe
}
# --------------------------------------------------------------------------------
#
# if not present, create /opt and create the QB64PE and the temporary install folders
#
create_folders()
{
    if [ ! -d "/opt" ]
        then
            mkdir /opt
        chmod -R 777 /opt
    fi
    mkdir "$TEMPFOLDER"
#    mkdir "$QB64PEFOLDER"
    chmod -R 777 "$TEMPFOLDER"
    chmod -R 777 "$QB64PEFOLDER"
    chown -f -R $MYUSERNAME $TEMPFOLDER

}
# --------------------------------------------------------------------------------
#
# install QB64PE and all the needed packages accordingly to the OS name
#
install_qb64pe()
{
#
# ask a question to keep the $TEMPFOLDER
#
    #dlg055="${BLUE}Now, just two more questions:"
    $ECHO "$dlg055"
    request_starter
    request_keep
#
# ask to start the install of QB64PE and all the needed dependencies
#
    request_start
#
# create the QB64PE and temp install folders
#
    create_folders
#
# get and install the needed dependencies to be enabled for QB64PE
#
    get_packages
#
#  get, compile and install QB64PE & InForm
#
    get_qb64pe
#
# if $TEMPFOLDER is not selected to be saved delete the installation temp folder
#
    delete_temp_folder
}
# --------------------------------------------------------------------------------
#
# ask for installing QB64PE
#
request_install()
{
    clear
    #dlg056="${BLUE}\nThe next step is to download and install QB64PE as well as all the relevent\ndependencies needed to compile QB64PE on $VENDOR $RELEASE.\n\nMeanwhile, be aware that this install can last up to 15 minutes due to the\ntime to download, compile and install QB64PE.\n\nSo, the speed of this installation depends both of the power of your machine\nand of your intrenet bandwith.\n"
    $ECHO "$dlg056"
    install_qb64pe
}
# --------------------------------------------------------------------------------
#
# get the response to continue the execution of the script
#
get_response_continue()
{
    case $CONTINUE in
        'N'|'n')
            #dlg057="${GREEN}You ended the script and nothing was done on your computer.\n\n${BLUE}Please restart this script when you need it.\n\nGoodbye.${BACK}$dlg000"
        $ECHO "$dlg057"; exit 0;;
        *)
            #dlg058="${GREEN}\nOK. Continuing the installation...${BACK}"
        $ECHO "$dlg058";;
    esac
}
# --------------------------------------------------------------------------------
#
# display the introduction dialog to present the script
#
display_intro()
{
    clear
    #dlg059="${BLUE}\nHello ${GREEN}$MYUSERNAME${BLUE},\n\nNow, this script installs QB64PE 1.3 as well as all the necessary dependencies\naccordingly to your distribution specifications.\n\nYour OS is: ${RED}$SYSTEM $VENDOR $RELEASE${BLUE} with the following characteristics:\n\n Name:    ${RED}$DISTRONAME\n ${BLUE}Flavor:  ${RED}$FLAVOR bits\n ${BLUE}Kernel:  ${RED}$KERNEL\n\n${BLUE}By default:\n\n The QB64PE install folder is: ${RED}$QB64PEFOLDER\n${BLUE} The TEMP install folder is: ${RED}$TEMPFOLDER\n\n${BLUE}If you want to modify these locations (${RED}highly unrecommended${BLUE}), please read the\ninstructions in the script source file and modify it accordingly to your needs."
    $ECHO "$dlg059"
    pause
}
# --------------------------------------------------------------------------------
#
# Special function to secure the use of wget
#
get_file()
{
    TRYCOUNT=0
    until wget -O $DESTINSTALL"/"$FILE2 $SOURCE$FILE
        do
            TRYCOUNT=$((TRYCOUNT+1))
            if [ "$TRYCOUNT" = "9" ]
                then
                    #dlg060="${RED}Sorry but after 9 tries, I can't download $SOURCE$FILE"
                    $ECHO "$dlg060"
                    $ECHO "${YELLOW}"
                    #dlg061="Do you wish to retry right now: y/N (empty return = No) ? : "
                    read -p "$dlg061" DOITAGAIN
                if [ "$DOITAGAIN" = "" ]
                    then
                        DOITAGAIN="N"
                        #dlg063="${RED}This script can't continue without $FILE2\n\n\${GREEN}Please verify your internet connection and restart the script.\n\nIf the problem persists, please repport to admin@as2.com\n\n${BLUE}Goodbye.${BACK}$dlg000"
                        $ECHO "$dlg063"$BACK
                        exit 0
                fi
                if [ "$DOITAGAIN" <> "N" ] || [ "$DOITAGAIN" <> "n" ]
                    then
                        #dlg062="${GREEN}Retrying to download $SOURCE$FILE"
                        $ECHO "$dlg062"
                        if [ $FILE = "qb64pe-$QB64PEREV2.tar.bz2" ]
                            then
                                FILE="qb64pe-$QB64PEREV2.tar.bz2"
                                FILE2=$FILE
                                SOURCE="http://$SERVERBACKUP/qb64pe/packages/"
                                get_file
                            elif [ $FILE = "InForm.tar.bz2" ]
                                then
                                    FILE="InForm.tar.bz2"
                                    FILE2=$FILE
                                    SOURCE="http://$SERVERBACKUP/qb64pe/packages/"
                                    get_file
                            elif  $FILE = "qb64pe-cmd.tar.bz2" ]
                                then
                                    FILE="qb64pe-cmd.tar.bz2"
                                    FILE2=$FILE
                                    SOURCE="http://$SERVERBACKUP/qb64pe/packages/"
                                    get_file
                        fi
                    else
                        #dlg063="${RED}This script can't continue without $FILE2\n\n\${GREEN}Please verify your internet connection and restart the script.\n\nIf the problem persists please repport to admin@as2.com\n\n${BLUE}Goodbye.${BACK}$dlg000"
                        $ECHO "$dlg063"$BACK
                        exit 0
                fi
            fi
        done
}
# --------------------------------------------------------------------------------
#
# Special function to secure the use of yum
#
get_packet()
{
    TRYGET=0
    if [ "$DISTRO_INSTALL" = "" ]
        then
            DISTRO_INSTALL="yum -y install "
    fi
    until $DISTRO_INSTALL$PACKET
        do
            TRYGET=$((TRYGET+1))
            if [ "$TRYGET" = "5" ]
                then
                    #dlg064="${RED}\nSorry but after ${BACK}5{RED} tries, I can't install $PACKET"
                    $ECHO "$dlg064"
                    $ECHO "${YELLOW}"
                    #dlg065="Do you wish to retry right now: y/N (empty return = No)? : "
                    read -p "$dlg065" TRYAGAIN
                if [ "$TRYAGAIN" = "" ]
                    then
                        TRYAGAIN="N"
                        pause
                        echo $TRYAGAIN
                        pause
                        exit 0
                fi
                case $TRYAGAIN in
                    'Y'|'y')
                        #dlg066="${GREEN}Retrying to install $PACKET"
                        $ECHO "$dlg066"; get_packet;;
                    *)
                        #dlg067="${RED}Sorry but this script can't continue without $PACKET\n\n${GREEN}Please verify your internet connection and restart the script.\n${BLUE}Goodbye${BACK}$dlg000"
                        $ECHO "$dlg067"; exit 0;;
                esac
            fi
        done
}
# --------------------------------------------------------------------------------
#
# check if lsb_release and wget are installed.
#
check_basepack()
{
    if [ "$ME" != "root" ]
        then
            #dlg074="${BLUE}Hello $ME,\n\n${RED}You must use the root priviledges to use this script.\n\n${GREEN}Please restart this script using [sudo] or [su].\n\n${BLUE}Goodbye.${BACK}\n\n--------------------------------------------------------------------------------\n"
            $ECHO "$dlg074"
            exit 0
    fi
    lsb=$(whereis lsb_release)
    if [ "$lsb" = "lsb_release:" ]
        then
            #dlg068="\n${BLUE}Hello $ME,${RED}\n\nYou must install lsb_release to use this script."
            $ECHO "$dlg068"
            $ECHO "${YELLOW}"
            #dlg069="Do you want to install lsb_release now: Y/n (empty return = Yes) ? "
            read -p "$dlg069" LSBRELEASE
            case $LSBRELEASE in
                'N'|'n')
                    #dlg070="${RED}This script can't continue without lsb_release.\n${GREEN}Please install lsb_release and restart the script.\n\n${BLUE}Goodbye.${BACK}$dlg000"
                    $ECHO "$dlg070"; exit 0;;
                *)
                    $ECHO "${BACK}"; PACKET="redhat-lsb-core"; get_packet; clear;;
            esac
    fi
    WGET=$(whereis wget)
    if [ "$WGET" = "wget:" ]
        then
            #dlg071="${RED}Please, you must install wget to use this script."
            $ECHO "$dlg071"
            $ECHO "${YELLOW}"
            #dlg072="Do you want to install wget now: Y/n (empty return = Yes) ? "
            read -p "$dlg072" GETWGET
            case $GETWGET in
                'N'|'n')
                    #dlg073="${GREEN}This script can't continue without wget.\nPlease install wget and restart the script.\n\n${BLUE}Goodbye.${BACK}$dlg000"
                    $ECHO "$dlg073"; exit 0;;
                *)
                    $ECHO "${BACK}"; PACKET="wget"; get_packet;;
            esac
    fi
}
# --------------------------------------------------------------------------------
#
# get the used tongue and set the Desktop name accordingly.
#
get_tongue()
{
    TONGUE=$($ECHO $LANG | cut -c1,2)
    case $TONGUE in
        'be')
            # change set_language_us to set_language_be when translated in Russian
            # done as of: 2016-12-18
            DESKTOP_NAME="Сталец"; set_language_be;;
        'de')
            # change set_language_us to set_language_de when translated in Deutch
            # done as of: 2016-12-18
            DESKTOP_NAME="Schreibtisch"; set_language_de;;
        'es')
            # change set_language_us to set_language_es when translated in Spanish
            # done as of: ????-??-??
            DESKTOP_NAME="Escritorio"; set_language_us;;
        'fr')
            # change set_language_us to set_language_fr when translated in French
            # done as of: 2016-11-23
            DESKTOP_NAME="Bureau"; set_language_fr;;
        'it')
            # to change set_language_us to set_language_it when translated in Italian
            # done as of: 2018-12-02
            DESKTOP_NAME="Scrivania"; set_language_it;;
        'pt')
            # change set_language_us to set_language_pt when translated in Portugese
            # done as of: 2016-12-23 thank you to Fellippe Heitor
            DESKTOP_NAME="Área de Trabalho"; set_language_pt;;
        *)
            # default language used for the dialog messages when not translated.
            # However, the $DESKTOP_NAME will not be valid for non translated language.
            DESKTOP_NAME="Desktop"; set_language_us;;
    esac
}
# --------------------------------------------------------------------------------
#
# get the OS vendor name
#
get_osname()
{
    if [ -e /etc/arch-release ]
        then
            VENDOR="Arch"
        elif [ -e /etc/fedora-release ]
            then
                VENDOR="Fedora"
        elif [ -e /etc/centos-release ]
            then
                VENDOR="CentOS"
        elif [ -e /etc/redhat-release ]
            then
                VENDOR="RedHat"
        elif [ "$VENDOR" = "" ]
            then
                VENDOR=$(lsb_release -si)
    fi
    if [ "$VENDOR" = "LinuxMint" ] || [ "$VENDOR" = "Linuxmint" ]
        then
            VENDOR="Mint"
    fi
    if [ "$VENDOR" = "ManjaroLinux" ]
        then
            VENDOR="Manjaro"
    fi
    if [ "$VENDOR" = "arch" ]
        then
            VENDOR="Arch"
    fi
    if [ "$VENDOR" = "neon" ]
        then
            VENDOR="Neon"
    fi
    if [ "$VENDOR" = "raspbian" ]
        then
            VENDOR="Raspbian"
    fi
}
#
# --------------------------------------------------------------------------------
#
# set the variables used in this script
#
set_variables()
{
#
#  assign prompt colors
#
    RED="\033[01;31m"
    GREEN="\033[01;32m"
    YELLOW="\033[01;33m"
    BLUE="\033[01;34m"
    PINK="\033[01;35m"
    CIAN="\033[01;36m"
    WHITE="\033[01;37m"
    BACK="\033[0m"
#
#  get the distribution flavor
#
    FLAVOR=$(getconf LONG_BIT)
#
#  define file folders
#
    QB64PEFOLDER="/opt/qb64pe"
    TEMPFOLDER="/opt/qb64pe-tmp"
#
#  get the user name
#
    ME=$USER
#
#  get the OS type
#
    SYSTEM=$(uname)
#
#  get the OS vendor name
#
    get_osname
#
# set the $ECHO command for the different sh or bash
#
    if [ "$VENDOR" = "Debian" ] || [ "$VENDOR" = "Raspbian" ] || [ "$VENDOR" = "Mint" ] || [ "$VENDOR" = "Ubuntu" ] || [ "$VENDOR" = "elementary" ] || [ "$VENDOR" = "Zorin" ] || [ "$VENDOR" = "Neon" ]
        then
            ECHO="echo "
        else
            ECHO="echo -e "
    fi
#
# get the tongue of the dialogs of the OS and set the messages accordingly
#
    get_tongue
#
# check if the lsb_release and wget packages are installed
#
    check_basepack
#
#  get the distribution name
#
    DISTRONAME="$(lsb_release -sd) $(lsb_release -sc)"
#
#  get the release number (e.g. 12.04)
#
    RELEASE=$(lsb_release -sr)
#
# get the description
#
    DESCRIPTION=$(lsb_release -sd)
#
#  get the kernel number
#
    KERNEL=$(uname -r)
#
#  define the needed dependencies to install for compiling QB64PE accordingly to the OS
#
    if [ "$VENDOR" = "Debian" ] || [ "$VENDOR" = "Raspbian" ] || [ "$VENDOR" = "elementary" ] || [ "$VENDOR" = "Mint" ] || [ "$VENDOR" = "Neon" ] || [ "$VENDOR" = "Ubuntu" ] ||  [ "$VENDOR" = "Zorin" ]
        then
            PACKAGES=" make g++ x11-utils mesa-common-dev libglu1-mesa-dev libasound2-dev zlib1g-dev"
        elif [ "$VENDOR" = "CentOS" ] || [ "$VENDOR" = "Fedora" ]
            then
                PACKAGES=" gcc-c++ make xmessage mesa-libGLU-devel alsa-lib-devel zlib-devel"
        elif [ "$VENDOR" = "RedHat" ]
            then
                PACKAGES=" gcc-c++ make mesa-libGLU alsa-lib xmessage mesa-libGLU-devel zlib-devel"
        elif [ "$VENDOR" = "Arch" ] || [ "$VENDOR" = "Bridge" ] || [ "$VENDOR" = "Manjaro" ] || [ "$VENDOR" = "Chakra" ]
            then
                PACKAGES=" gcc make zlib xorg-xmessage"
        elif [ "$VENDOR" = "voidlinux" ]
            then
                PACKAGES="gcc make xmessage glu-devel zlib-devel alsa-lib-devel"
    fi
#
# define the system command to install the dependencies accordingly to the distros
#
    case $VENDOR in
        'Debian'|'Raspbian'|'elementary'|'Mint'|'Ubuntu'|'Zorin'|'Neon')
            DISTRO_INSTALL="apt-get -y install ";;
        'Fedora')
            DISTRO_INSTALL="dnf -y install ";;
        'CentOS'|'RedHat')
            DISTRO_INSTALL="yum -y install ";;
        'Arch'|'Bridge'|'Manjaro'|'Chakra')
            DISTRO_INSTALL="pacman -S --noconfirm ";;
         'Fvoidlinux')
            DISTRO_INSTALL="sudo xbps-install -Sy ";;
    esac
#
# The QB64PE version to be displayed by the script.
#
    QB64PEREV="QB64PE (Phoenix Edition) version 3.3.0"
#
# The QB64PE version to be downloaded by the script.
#
    QB64PEREV2="3.3.0_lnx"
#
# The InFom version to be downloaded by the script.
#
    INFORMREV="1.3"
#
# The script version to be displayed by the script.
#
    SCRIPTREV="r04"
#
# The remote or local server address used by the script.
#
#    SERVER="l7d.ddns.net" # here is my official server address here and REM the next line
    SERVER="192.168.10.101" # put your own local server address here and REM the previous line
#    SERVERBACKUP="90.39.157.199" # put you own server backup address here and REM the next line
    SERVERBACKUP="192.168.10.101" # put you own local server backup address here and REM the previous line

#
# Don't aks why, but don't remove the line below even if the command was already done.
#
    get_tongue # I know, it's already done. Don't ask why. Don't remove this line.
}
# --------------------------------------------------------------------------------
#
# End of definitons and functions
#
# ================================================================================
#
# Start the execution of this script
#
# --------------------------------------------------------------------------------
clear
set_variables
show_info
check_priviledges
check_qb64pe
check_dependencies
display_intro
request_install
exit 0
# --------------------------------------------------------------------------------
#
# End of the script.
#
# ================================================================================
